"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[2628],{22628:(t,r,a)=>{var e=a(28612),o=a(37095),p=a(31091),s=a(66960),h=a(33392),n=a(35599),c=a(73005),f=a(30670),i=Array,m=Math.max,u=Math.min;e({target:"Array",proto:!0},{toSpliced:function(t,r){var a,e,o,l,b=n(this),k=s(b),w=h(t,k),d=arguments.length,g=0;for(0===d?a=e=0:1===d?(a=0,e=k-w):(a=d-2,e=u(m(c(r),0),k-w)),o=p(k+a-e),l=i(o);g<w;g++)f(l,g,b[g]);for(;g<w+a;g++)f(l,g,arguments[g-w+2]);for(;g<o;g++)f(l,g,b[g+e-a]);return l}}),o("toSpliced")}}]);
//# sourceMappingURL=2628.fdc22232481947b34b28.js.map