"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[2321],{22321:(e,t,s)=>{s.r(t),s.d(t,{default:()=>f});var a=s(36418),r=s.n(a),i=s(37270),o=s(45955),n=s(7430),l=s(14778),u=s(61486),c=s(79751),d=s(20463),m=s(25695),_=s(19408),p=s(78451),g=s(11039),E=s(47551),I=s(56158);function M(){return function(){const e=(0,E.A)(),t=(0,i.useDispatch)(),s=(0,l.useIntl)(),[a,r]=(0,g.A)(),o=(0,i.useSelector)(d.ks),n=a?.messages?.history,[M,f]=(0,I.A)(p.pm.CATEGORY_CLOUD_LIMITS,p.pm.SHOWN_LIMITS_REACHED_ON_LOGIN),{openPricingModal:h,isAirGapped:y}=(0,_.A)();if(r&&e.messages.historyLoaded&&void 0!==n&&o&&"true"!==M){if(e.messages.history>n){f("true");const e={title:(0,l.defineMessage)({id:"workspace_limits.modals.limits_reached.title",defaultMessage:"{limitName} limit reached",values:{limitName:s.formatMessage({id:"workspace_limits.modals.limits_reached.title.message_history",defaultMessage:"Message history"})}}),description:(0,l.defineMessage)({id:"workspace_limits.modals.limits_reached.description.message_history",defaultMessage:"Your sent message history is no longer available but you can still send messages. Upgrade to a paid plan and get unlimited access to your message history."}),secondaryAction:{message:(0,l.defineMessage)({id:"workspace_limits.modals.close",defaultMessage:"Close"}),onClick:()=>{t((0,c.O)(p.IQ.CLOUD_LIMITS))}},onClose:()=>{t((0,c.O)(p.IQ.CLOUD_LIMITS))}};y||(e.primaryAction={message:(0,l.defineMessage)({id:"workspace_limits.modals.view_plan_options",defaultMessage:"View plan options"}),onClick:()=>{t((0,c.O)(p.IQ.CLOUD_LIMITS)),h()}}),t((0,c.q)({modalId:p.IQ.CLOUD_LIMITS,dialogType:m.A,dialogProps:e}))}t((0,u.Qq)(!1))}}(),null}function f(){const e=(0,i.useSelector)(o.I0),t=(0,i.useSelector)(n.J1);return e&&t?r().createElement(M,null):null}},56158:(e,t,s)=>{s.d(t,{A:()=>l});var a=s(36418),r=s(37270),i=s(35631),o=s(3569),n=s(77440);function l(e,t){const s=(0,r.useDispatch)(),l=(0,r.useSelector)(o.WR),u=(0,r.useSelector)((s=>(0,n.Jt)(s,e,t))),c=(0,a.useCallback)((a=>{const r={category:e,name:t,user_id:l,value:a};return s((0,i.SF)(l,[r]))}),[e,s,t,l]);return(0,a.useMemo)((()=>[u,c]),[u,c])}},61486:(e,t,s)=>{s.d(t,{N5:()=>u,Qp:()=>c,Qq:()=>n,p$:()=>l,rN:()=>d});var a=s(1418),r=s(87988),i=s(40693),o=s(78451);function n(e){return{type:o.Q3.NEEDS_LOGGED_IN_LIMIT_REACHED_CHECK,data:e}}function l(e){return e?{type:o.Q3.SET_ADMIN_CONSOLE_USER_MANAGEMENT_TABLE_PROPERTIES,data:e}:{type:o.Q3.CLEAR_ADMIN_CONSOLE_USER_MANAGEMENT_TABLE_PROPERTIES,data:null}}function u(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};return async(t,s)=>{let o;try{o=await i.mT.getUsersForReporting(e)}catch(e){return(0,r.UP)(e,t,s),t((0,a.vV)(e)),{error:e}}return{data:o}}}function c(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};return async(t,s)=>{let o;try{o=await i.mT.getUserCountForReporting(e)}catch(e){return(0,r.UP)(e,t,s),t((0,a.vV)(e)),{error:e}}return{data:o}}}function d(){let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};return async(t,s)=>{try{await i.mT.startUsersBatchExport(e)}catch(e){return(0,r.UP)(e,t,s),t((0,a.vV)(e)),{error:e}}return{data:!0}}}}}]);
//# sourceMappingURL=2321.a08911886b493ed5409b.js.map