{{define "globalrelay_compliance_export_message"}}
<li class="message">
    <span class="post_id">{{.Props.PostId}}</span>
    <span class="sent_time">{{.Props.SentTime}}</span>
    <span class="username">@{{.Props.Username}}</span>
    <span class="userid">{{.Props.UserId}}</span>
    <span class="postusername">{{.Props.PostUsername}}</span>
    <span class="usertype">{{.Props.UserType}}</span>
    <span class="email">({{.Props.Email}})</span>
    <span class="message">{{.Props.Message}}</span>{{ if .Props.PreviewsPost }}
    <span class="previews_post">{{.Props.PreviewsPost}}</span>{{ end }}{{ if .Props.UpdateType }}
    <span class="update_type">{{.Props.UpdateType}}</span>
    <span class="update_time">{{.Props.UpdateTime}}</span>
    <span class="edited_new_msg_id">{{.Props.EditedNewMsgId}}</span>{{ end }}
</li>
{{end}}
