.SelectTeam__sub-header{display:flex;align-items:center;justify-content:space-between;margin-top:10px;margin-bottom:24px}.SelectTeam__sub-header>h4{margin:0}.SelectTeam__sub-header>h4 span{display:inline-flex;font-size:20px;font-weight:600;line-height:28px}.SelectTeam__sub-header a.LearnAboutTeamsLink{display:flex;align-items:center;padding:6px 18px;column-gap:10px}.SelectTeam__sub-header a.LearnAboutTeamsLink:hover,.SelectTeam__sub-header a.LearnAboutTeamsLink:focus,.SelectTeam__sub-header a.LearnAboutTeamsLink:active{text-decoration:none}.SelectTeam__sub-header a.LearnAboutTeamsLink>i{display:inline-flex;padding:3px;border-radius:50%;background-color:rgba(var(--button-bg-rgb), 0.08);font-size:14px}.SelectTeam__sub-header a.LearnAboutTeamsLink>i::before{margin:0}.SelectTeam__sub-header a.LearnAboutTeamsLink span{font-size:12px;font-weight:600;line-height:16px}.SelectTeam__sub-header a.LearnAboutTeamsLink span:hover{text-decoration:underline}

/*# sourceMappingURL=3461.f5137c65d0921245e459.css.map*/