"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[1300],{21300:(t,e,n)=>{n.r(e),n.d(e,{default:()=>f});var a=n(37270),c=n(32446),s=n(65952),r=n(14776),o=n(7430),u=n(11638),m=n(36418),d=n.n(m);const p=t=>{const e=(0,m.useRef)(!1),[n,a]=(0,m.useState)(!1);(0,m.useEffect)((()=>(e.current=!0,()=>{e.current=!1})),[]);const c=(0,m.useCallback)((async()=>{const n=t.match.params.postid;await t.actions.focusPost(n,t.returnTo,t.currentUserId),e.current&&a(!0)}),[t.match.params.postid,t.returnTo,t.currentUserId,t.actions]);return(0,m.useEffect)((()=>{document.body.classList.add("app__body"),c()}),[c]),n&&t.channelId&&t.teamName?null:d().createElement("div",{id:"app-content",className:"app__content"})},i=(0,m.memo)(p),f=(0,a.connect)((function(t){const e=(0,r.H7)(t),n=(0,s.Lw)(t),a=(0,o.WR)(t);return{channelId:n?n.id:"",teamName:e?e.name:"",currentUserId:a}}),(function(t){return{actions:(0,c.zH)({focusPost:u.V},t)}}))(i)}}]);
//# sourceMappingURL=1300.28219bfe0e5db60ce6fe.js.map