.feature_toast{position:fixed;z-index:var(--z-index-popover);top:72px;right:60px;display:flex;width:386px;align-items:flex-start;padding:24px;border:var(--border-default);border-radius:var(--radius-s);background-color:var(--center-channel-bg);gap:12px}.feature_toast__actions{padding:4px 0}.feature_toast__header_content{display:flex;width:100%;align-items:flex-start;gap:8px}.feature_toast__header_content h3{flex-grow:1;padding-top:6px;margin:0;font-size:14px;font-weight:600;line-height:20px}.feature_toast__icon{flex-shrink:0;margin-top:4px}.feature_toast__main_content{display:flex;flex-direction:column;flex-grow:1;align-items:baseline;gap:8px}.feature_toast__main_content p{margin:0}.feature_toast__main_content mark+mark{margin-left:4px}

/*# sourceMappingURL=6233.f58a3f62b51920c9bf1a.css.map*/