#SidebarContainer .SidebarDrafts .SidebarChannel{height:100%}#SidebarContainer .SidebarDrafts .SidebarLink{width:100%}#SidebarContainer .SidebarDrafts .SidebarLink .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.75);vertical-align:middle}#SidebarContainer .SidebarDrafts .SidebarLink .badge{background:rgba(0,0,0,0);color:var(--sidebar-text)}#SidebarContainer .SidebarDrafts .SidebarLink .badge .icon.icon-draft-indicator{font-size:14px !important}#SidebarContainer .SidebarDrafts .SidebarLink:hover{padding-right:16px}#SidebarContainer .SidebarDrafts .SidebarLink:hover .badge{position:initial;visibility:visible}#SidebarContainer .SidebarDrafts .SidebarLink #unreadMentions{color:rgba(var(--sidebar-text-rgb), 0.64);margin-inline:0}#SidebarContainer .SidebarDrafts .SidebarLink #unreadMentions:not(.urgent){padding-inline:0}#SidebarContainer .SidebarDrafts .SidebarLink #unreadMentions.scheduledPostBadge{margin-left:8px;padding-block:2px}#SidebarContainer .SidebarDrafts .SidebarLink #unreadMentions.scheduledPostBadge.urgent{color:var(--sidebar-text)}#SidebarContainer .SidebarDrafts .SidebarLink #unreadMentions.scheduledPostBadge .unreadMentions{position:relative;top:-0.5px}#SidebarContainer .SidebarDrafts .SidebarLink.active #unreadMentions{color:var(--sidebar-text)}.sidebar--left .SidebarDrafts{padding-bottom:0;margin-top:13px}.sidebar--left .SidebarDrafts .icon{width:auto;padding-left:1px;margin-top:1px}.sidebar--left .SidebarDrafts .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.75)}.sidebar--left .SidebarDrafts .SidebarChannelLinkLabel_wrapper{display:flex;flex:1}.sidebar--left .SidebarDrafts .badge{margin:0 12px 0 0}

/*# sourceMappingURL=2539.9f230f0ff508da71cd09.css.map*/