.attachment__truncated{overflow:hidden;min-width:0;text-overflow:ellipsis;white-space:nowrap}
.file_card{display:flex;width:300px;height:40px;flex-direction:row;align-items:center;padding:0 6px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:0 2px;color:var(--center-channel-color)}.file_card__name{overflow:hidden;min-width:0;flex-shrink:1;margin-right:4px;text-overflow:ellipsis;white-space:nowrap}.file_card__size{flex-shrink:0;margin-left:auto;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px}.file_card__image{min-width:28px;max-width:28px;min-height:28px;max-height:28px;border-radius:2px;margin-right:8px}.file_card__attachment{margin-right:4px;color:rgba(var(--center-channel-color-rgb), 0.5)}.file_card__attachment[class*=text]{color:rgba(var(--center-channel-color-rgb), 0.5)}.file_card__attachment[class*=excel]{color:#1ca660}.file_card__attachment[class*=pdf],.file_card__attachment[class*=powerpoint]{color:#ed522a}.file_card__attachment[class*=generic],.file_card__attachment[class*=code],.file_card__attachment[class*=image],.file_card__attachment[class*=audio],.file_card__attachment[class*=video],.file_card__attachment[class*=word],.file_card__attachment[class*=patch],.file_card__attachment[class*=svg]{color:#338aff}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.ThreadItem{position:relative;padding:18px 18px 18px 28px;cursor:pointer;text-align:left}.ThreadItem .alt-visible{visibility:hidden}.ThreadItem:hover,.ThreadItem:focus,.ThreadItem:focus-within,.ThreadItem:has([aria-expanded=true]){background:rgba(var(--center-channel-color-rgb), 0.04)}.ThreadItem:hover .alt-visible,.ThreadItem:focus .alt-visible,.ThreadItem:focus-within .alt-visible,.ThreadItem:has([aria-expanded=true]) .alt-visible{visibility:unset}.ThreadItem:hover .alt-hidden,.ThreadItem:focus .alt-hidden,.ThreadItem:focus-within .alt-hidden,.ThreadItem:has([aria-expanded=true]) .alt-hidden{visibility:hidden}.ThreadItem__author{overflow:hidden;overflow:hidden;max-width:100%;text-align:left;text-overflow:ellipsis;-moz-user-select:all;white-space:nowrap}.ThreadItem__tags{display:flex;max-width:100%;align-items:center;gap:4px}.ThreadItem.is-selected{background:rgba(var(--button-bg-rgb), 0.04)}.ThreadItem.is-selected:hover,.ThreadItem.is-selected:focus{background:rgba(var(--button-bg-rgb), 0.08)}.ThreadItem .activity{display:flex;align-items:center;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:600;line-height:15px}.ThreadItem.has-unreads .activity{color:rgba(var(--sidebar-text-active-border-rgb), 1)}.ThreadItem .dot-unreads{display:inline-block;width:8px;height:8px;border-radius:50%;margin:0 8px;background:rgba(var(--sidebar-text-active-border-rgb), 1);text-align:center}.ThreadItem .dot-mentions{display:inline-block;width:16px;height:16px;border-radius:50%;background:rgba(var(--button-bg-rgb), 1);color:rgba(var(--button-color-rgb), 1);font-size:10px;font-weight:700;line-height:16px;text-align:center}.ThreadItem .dot-mentions.over{font-size:8px}.ThreadItem .indicator{position:absolute;left:-24px;display:grid;width:24px;height:20px;place-content:center}.ThreadItem>.thread-item-header{position:relative;display:grid;margin:0 0 6px;font-family:"Open Sans",sans-serif;font-size:14px;font-weight:600;gap:10px;grid-template-columns:minmax(0, min-content) minmax(0, auto) min-content;justify-items:start;line-height:20px;white-space:nowrap}.ThreadItem>.thread-item-header>time{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:normal;grid-column:3/4;line-height:20px}.ThreadItem div.preview{height:40px;margin:0 0 10px;color:rgba(var(--center-channel-color-rgb), 1);display:-webkit-box;overflow:hidden;-webkit-box-orient:vertical;-webkit-line-clamp:2;max-height:40px}.ThreadItem .menu-anchor{position:absolute;top:12px;right:14px}.ThreadItem .menu-anchor .Button{width:28px;height:28px;padding:0;font-size:18px}.ThreadItem .MenuWrapper .dropdown-menu{min-width:250px}.ThreadItem .Avatars{margin-right:10px}.ThreadItem .btn:focus-visible,.ThreadItem .btn[aria-expanded=true]{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.no-results__wrapper .thread-no-results-subtitle-shortcut .shortcut-key{padding:2px 5px;background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:600;line-height:16px}
.ThreadList{display:grid;overflow:hidden;grid-template-areas:"header" "list";grid-template-rows:56px 1fr}.ThreadList .Header{padding-right:12px;padding-left:12px;border-bottom:var(--border-default);color:rgba(var(--center-channel-color-rgb), 0.75);grid-area:header}.ThreadList .Header .tab-buttons-list{display:flex}.ThreadList .Header .tab-button-wrapper{position:relative;display:flex;height:100%;justify-content:center;padding:12px 0}.ThreadList .Header .tab-button-wrapper+.tab-button-wrapper{margin-left:4px}.ThreadList .Header .tab-button-wrapper Button{display:flex;max-width:100%}.ThreadList .Header .tab-button-wrapper Button .Button_label{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.ThreadList .Header .left{display:grid;height:100%;grid-template-columns:minmax(0, auto) minmax(0, auto)}.ThreadList .Header .right-anchor .Button{padding:4px 0}.ThreadList .Header .right-anchor .Button:disabled{cursor:not-allowed}.ThreadList .threads{margin-right:5px;grid-area:list}.ThreadList .threads .no-results__wrapper{position:relative;top:-28px;max-width:100%}.ThreadList .threads .no-results__wrapper .thread-no-results-title{margin-bottom:0;font-size:16px;line-height:24px}.ThreadList .threads .no-results__wrapper .thread-no-results-subtitle{max-width:100%;font-size:12px}.ThreadList .threads .no-results__wrapper .thread-no-results-subtitle .thread-no-results-subtitle-shortcut{margin:0}.ThreadList .ThreadItem{border-bottom:var(--border-default)}.ThreadList .virtualized-thread-list{scrollbar-color:var(--center-channel-color-32) hsla(0,0%,100%,0);scrollbar-width:thin}.ThreadList .virtualized-thread-list .no-results__icon svg{width:92px;height:73px;margin-bottom:0px}
.GlobalThreads___title span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.rhs-open #channel_view.channel-view:has(.GlobalThreads){padding-right:0}.rhs-open #channel_view.channel-view:has(.GlobalThreads) .ThreadPane,.rhs-open #channel_view.channel-view:has(.GlobalThreads) .no-results__holder{padding-right:18px}.GlobalThreads{--list: minmax(min-content, 300px);--pane: auto;display:grid;overflow:hidden;grid-template-areas:"list pane";grid-template-columns:var(--list) var(--pane);grid-template-rows:1fr}.GlobalThreads .GlobalThreads___header{border-bottom:var(--border-default);grid-area:header}.GlobalThreads .channel-header__icon,.GlobalThreads .search__form{margin-top:1px}.GlobalThreads .ThreadList{grid-area:list}.GlobalThreads .ThreadPane,.GlobalThreads .ThreadList+.no-results__holder{box-shadow:var(--elevation-2);grid-area:pane;outline:var(--border-light)}.GlobalThreads>.no-results__holder{grid-area:list/list/pane/pane}@media screen and (max-width: 1020px){.GlobalThreads>.no-results__holder{grid-area:main}}.GlobalThreads .no-results__wrapper svg{margin-bottom:20px}.GlobalThreads .no-results__subtitle{max-width:378px}.GlobalThreads .ThreadPane{position:relative;overflow:hidden}@media screen and (max-width: 1020px){.GlobalThreads{grid-template-areas:"main main"}.GlobalThreads:not(.thread-selected) .ThreadList{grid-area:main}.GlobalThreads:not(.thread-selected) .ThreadPane,.GlobalThreads:not(.thread-selected) .ThreadList+.no-results__holder{display:none}.GlobalThreads.thread-selected .ThreadList{display:none}.GlobalThreads.thread-selected .ThreadPane{grid-area:main}.GlobalThreads.thread-selected .ThreadPane .Header{padding-left:5px}.GlobalThreads.thread-selected .ThreadPane .back{display:unset}}@media screen and (max-width: 768px){.GlobalThreads>.Header{display:none}.GlobalThreads .Header{border-top:var(--border-default)}}@media screen and (min-width: 1021px){.GlobalThreads{--list: minmax(min-content, 350px)}}@media screen and (min-width: 1267px){.GlobalThreads{--list: minmax(min-content, 400px)}}@media screen and (min-width: 1680px){.GlobalThreads{--list: minmax(min-content, 500px)}}

/*# sourceMappingURL=9766.731b794ceb64d08451f0.css.map*/