"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[3797],{73797:(e,t,a)=>{a.r(t),a.d(t,{default:()=>m});var n=a(36418),c=a.n(n),o=a(37270),r=a(65952),s=a(59359),l=a(78451);const u=()=>{const e=(0,o.useSelector)(r.eH);return e?c().createElement(s.A,{location:l.Hc.CENTER,rootId:"",channelId:e}):null},m=c().memo(u)}}]);
//# sourceMappingURL=3797.fe700a4b385867fc6b60.js.map