"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[8022],{28022:(e,t,s)=>{s.r(t),s.d(t,{getModule:()=>a,setModule:()=>u});const p={},a=e=>p[e],u=(e,t)=>!p[e]&&(p[e]=t,!0)}}]);
//# sourceMappingURL=8022.48e3ab6a5120f675fad7.js.map