{{define "warn_metric_ack"}}

<table align="center" border="0" cellpadding="0" cellspacing="0" width="100%"
    style="margin-top: 20px; line-height: 1.7; color: #555;">
    <tr>
        <td>
            <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%"
                style="max-width: 660px; font-family: Helvetica, Arial, sans-serif; font-size: 14px; background: #FFF;">
                <tr>
                    <td style="border: 1px solid #ddd;">
                        <table border="0" cellpadding="0" cellspacing="0"
                            style="padding: 20px 50px 0; text-align: center; margin: 0 auto">
                            <tr>
                                <td style="border-bottom: 1px solid #ddd; padding: 0 0 20px;">
                                    <h2 style="font-weight: normal; margin-top: 10px;">{{.Props.Title}}</h2>
                                    <p>{{.Props.Info}}<br>{{.Props.Warning}}</p>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <table border="0" cellpadding="0" cellspacing="0"
                                        style="padding: 20px 50px 0; text-align: center; margin: 0 auto">
                                        <!-- {{if .Props.ContactNameValue}} -->
                                        <tr>
                                            <td style="border: 0; padding: 0 0 0 20px; text-align: left;">
                                                <p style="font-weight: bold; margin-top: 0;">
                                                    {{.Props.ContactNameHeader}}
                                                    {{.Props.ContactNameValue}}</p>
                                            </td>
                                        </tr>
                                        <!-- {{end}} -->
                                        {{if .Props.ContactEmailValue}}
                                        <tr>
                                            <td style="border: 0; padding: 0 0 0 20px; text-align: left;">
                                                <p style="font-weight: bold; margin-top: 0;">
                                                    {{.Props.ContactEmailHeader}}
                                                    {{.Props.ContactEmailValue}}</p>
                                            </td>
                                        </tr>
                                        {{end}}
                                        {{if .Props.RegisteredUsersValue}}
                                        <tr>
                                            <td style="border: 0; padding: 0 0 0 20px; text-align: left;">
                                                <p style="font-weight: bold; margin-top: 0;">
                                                    {{.Props.RegisteredUsersHeader}}
                                                    {{.Props.RegisteredUsersValue}}</p>
                                            </td>
                                        </tr>
                                        {{end}}
                                        {{if .Props.SiteURL}}
                                        <tr>
                                            <td style="border: 0; padding: 0 0 0 20px; text-align: left;">
                                                <p style="font-weight: bold; margin-top: 0;">{{.Props.SiteURLHeader}}
                                                    {{.Props.SiteURL}}</p>
                                            </td>
                                        </tr>
                                        {{end}}
                                        {{if .Props.TelemetryIdValue}}
                                        <tr>
                                            <td style="border: 0; padding: 0 0 0 20px; text-align: left;">
                                                <p style="font-weight: bold; margin-top: 0;">
                                                    {{.Props.TelemetryIdHeader}}
                                                    {{.Props.TelemetryIdValue}}</p>
                                            </td>
                                        </tr>
                                        {{end}}
                                    </table>
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
                <tr>
                    {{template "email_footer" . }}
                </tr>
            </table>
        </td>
    </tr>
</table>
</td>
</tr>
</table>

{{end}}
