.clInput{display:block;margin-bottom:20px}.clWrapper{width:auto;padding:25px;margin-bottom:20px}.clCenterBackground{background-color:var(--center-channel-bg)}.clSidebarBackground{background-color:var(--sidebar-bg)}.clTable{width:100%;max-width:970px;background-color:var(--center-channel-bg)}.clTable th{text-transform:capitalize}.clTable tr{background-color:var(--center-channel-bg)}.clTable th,.clTable td{padding:12px 10px;text-align:center}.clTable th.inverted,.clTable td.inverted{background-color:var(--sidebar-bg)}

/*# sourceMappingURL=5258.78d70eb7bde9c9c58e36.css.map*/