{{define "email_footer"}}

<td style="text-align: center;color: #AAA; font-size: 11px; padding-bottom: 10px;">
    <p style="padding: 0 50px;">
        {{.Props.Organization}}<br>
        {{.Props.Footer}}
    </p>
</td>

{{end}}
