"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[1428],{71428:(e,a,t)=>{t.r(a),t.d(a,{default:()=>M});var n=t(71633),r=t.n(n),s=t(36418),l=t.n(s),i=t(14778),o=t(37270),d=t(81911),u=t(71892),c=t(77440),m=t(62563),h=t(2386),b=t(75270),_=t(45697),p=t(78451),g=t(3295);const C=e=>l().createElement("svg",Object.assign({width:"18",height:"18",viewBox:"0 0 14 13",fill:"none",xmlns:"http://www.w3.org/2000/svg"},e),l().createElement("path",{d:"M11.7952 0.00524884C12.1312 0.00524884 12.4144 0.125249 12.6448 0.365248C12.8848 0.595648 13.0048 0.878848 13.0048 1.21485V8.41485C13.0048 8.75085 12.8848 9.03405 12.6448 9.26445C12.4144 9.49485 12.1312 9.61005 11.7952 9.61005H3.4L0.9952 12.0148V1.21485C0.9952 0.878848 1.1104 0.595648 1.3408 0.365248C1.5808 0.125249 1.8688 0.00524884 2.2048 0.00524884H11.7952ZM2.2048 1.21485V9.10605L2.896 8.41485H11.7952V1.21485H2.2048ZM3.4 3.01485H10.6V4.21005H3.4V3.01485ZM3.4 5.40525H8.8V6.61485H3.4V5.40525Z"}));var k=t(3490);const f=(0,i.defineMessages)({urgentMention:{id:"channel_mention_badge.urgent_tooltip",defaultMessage:"You have an urgent mention"}}),M=()=>{const{formatMessage:e}=(0,i.useIntl)(),a=(0,o.useDispatch)(),t=(0,o.useSelector)(c.WW),{url:n}=(0,d.useRouteMatch)(),{pathname:M}=(0,d.useLocation)(),v=null!=(0,d.matchPath)(M,{path:"/:team/threads/:threadIdentifier?"}),{currentTeamId:E,currentUserId:L}=(0,k.K)(),w=(0,o.useSelector)(m.kL),H=w?.total_unread_threads,S=(0,o.useSelector)(b.A),I=(0,o.useSelector)(b.bM),V=(0,s.useCallback)((e=>{e.stopPropagation(),performance.mark(g.CU.GlobalThreadsLinkClicked),S&&I===p._n.EDIT_HISTORY&&a((0,h.bP)())}),[S,I]);return(0,s.useEffect)((()=>{t&&a((0,u.H_)(L,E))}),[L,E,t]),t?l().createElement("ul",{className:"SidebarGlobalThreads NavGroupContent nav nav-pills__container"},l().createElement("li",{id:"sidebar-threads-button",className:r()("SidebarChannel",{active:v,unread:H}),tabIndex:-1},l().createElement(d.Link,{onClick:V,to:`${n}/threads`,id:"sidebarItem_threads",draggable:"false",className:r()("SidebarLink sidebar-item",{"unread-title":Boolean(H)}),tabIndex:0},l().createElement("span",{className:"icon"},l().createElement(C,null)),l().createElement("div",{className:"SidebarChannelLinkLabel_wrapper"},l().createElement("span",{className:"SidebarChannelLinkLabel sidebar-item__name"},e({id:"globalThreads.sidebarLink",defaultMessage:"Threads"}))),w?.total_unread_mentions>0&&l().createElement(_.A,{unreadMentions:w.total_unread_mentions,hasUrgent:Boolean(w?.total_unread_urgent_mentions),tooltip:w?.total_unread_urgent_mentions?f.urgentMention:void 0})))):null}}}]);
//# sourceMappingURL=1428.d7b13f0da79083614a2d.js.map