
._rfx31ssb:before{border-radius:50%}
._15m6ys7w:before{border-color:var(--stroke-color)}
._3l8810ly:before{border-width:var(--stroke-width)}
._kzdanqa1:before{border-style:solid}._13y0usvi:before{box-sizing:border-box}
._154ifghn{top:var(--line-main-axis-start)}
._154ihv0e{top:var(--main-axis-offset)}
._19wo70hn:before{bottom:var(--terminal-cross-axis-offset)}
._1auk70hn:before{top:var(--terminal-cross-axis-offset)}
._1aukuj5p:before{top:var(--terminal-main-axis-start)}
._1bsb10ly{width:var(--stroke-width)}
._1cs8stnw:before{position:absolute}
._1e02fghn{inset-inline-start:var(--line-main-axis-start)}
._1e0c1ule{display:block}
._1kt9b3bt:before{content:""}
._1ltvhv0e{left:var(--main-axis-offset)}
._1mp4vjfa:before{width:var(--terminal-diameter)}
._1pbykb7n{z-index:1}
._1xi2hv0e{right:var(--main-axis-offset)}
._4t3i10ly{height:var(--stroke-width)}
._94n5hv0e{bottom:var(--main-axis-offset)}
._94n5idpf{bottom:0}
._bfhkys7w{background-color:var(--stroke-color)}
._cfu11ld9:before{display:var(--terminal-display)}
._kfgtvjfa:before{height:var(--terminal-diameter)}
._kqswstnw{position:absolute}
._lcxvglyw{pointer-events:none}
._ooun70hn:before{right:var(--terminal-cross-axis-offset)}
._qnec70hn:before{left:var(--terminal-cross-axis-offset)}
._rjxpidpf{inset-inline-end:0}
._z5wtuj5p:before{inset-inline-start:var(--terminal-main-axis-start)}
.app__body .modal .GenericModal.channel-bookmarks-create-modal .modal-body .form-control{height:40px;border:unset}.channel-bookmarks-create-modal .linkInput{margin-bottom:3rem;color:rgba(var(--center-channel-color-rgb), 0.72)}.channel-bookmarks-create-modal .Input___customMessage{line-height:14px}.channel-bookmarks-create-modal .LoadingSpinner{padding:10px 12px;font-size:16px}
.channel-bookmarks-container{scrollbar-width:thin}.bookmarkMeasureItem{position:absolute;pointer-events:none;visibility:hidden}.channelBookmarksMenuButton{position:relative;display:flex;padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);font-family:Open Sans;font-size:12px;font-weight:600;gap:5px}.channelBookmarksMenuButton.withLabel{padding:4px 12px 4px 6px;border-radius:12px}.channelBookmarksMenuButton[disabled]{background:rgba(var(--center-channel-color-rgb), 0.04);color:rgba(var(--center-channel-color-rgb), 0.56)}.channelBookmarksMenuButton:hover:enabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.channelBookmarksMenuButton:active:enabled,.channelBookmarksMenuButton[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08);color:rgb(var(--button-bg-rgb))}.channelBookmarksDotMenuButton{display:flex;width:18px;height:18px;align-items:center;padding:0;border:none;border-radius:4px;background:rgba(var(--center-channel-color-rgb), 8%);background:color-mix(in sRGB, var(--center-channel-bg), var(--center-channel-color) 8%);color:rgba(var(--center-channel-color-rgb), 0.56);font-family:Open Sans;font-size:12px;font-weight:600}.channelBookmarksDotMenuButton:hover{background:rgba(var(--button-bg-rgb), 16%);background:color-mix(in sRGB, var(--center-channel-bg), var(--center-channel-color) 16%);color:rgba(var(--center-channel-color-rgb), 0.72)}.channelBookmarksDotMenuButton:focus-visible{box-shadow:0 0 0 2px var(--link-color) inset;outline:none}.channelBookmarksDotMenuButton:active,.channelBookmarksDotMenuButton[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 16%);background:color-mix(in sRGB, var(--center-channel-bg), var(--button-bg) 16%);color:rgb(var(--button-bg-rgb))}.channelBookmarksDotMenuButton.channelBookmarksDotMenuButton--overflow{width:28px;height:28px;justify-content:center;border-radius:4px}#bookmark-create-file-input,#bookmark-create-file-input-in-modal{display:none}.channelBookmarksBarMenuButton{display:flex;align-items:center;padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font-size:12px;font-weight:600;gap:1px}.channelBookmarksBarMenuButton.withLabel{padding:4px 12px 4px 6px;border-radius:12px;gap:4px}.channelBookmarksBarMenuButton:hover:not(:disabled){background:rgba(var(--center-channel-color-rgb), 0.12);color:rgba(var(--center-channel-color-rgb), 0.88)}.channelBookmarksBarMenuButton:active:not(:disabled),.channelBookmarksBarMenuButton[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08);color:rgb(var(--button-bg-rgb))}.channelBookmarksBarMenuButton:disabled{cursor:not-allowed;opacity:.5}.bookmarkDragPreview{display:inline-block;overflow:hidden;max-width:25rem;padding:4px 12px;border-radius:12px;background:var(--center-channel-bg);box-shadow:0 4px 12px rgba(0,0,0,.15);color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:600;line-height:16px;text-overflow:ellipsis;white-space:nowrap}.overflowBookmarkItem.MuiMenuItem-root{position:relative;min-height:36px;padding-top:2px;padding-right:12px;padding-bottom:2px}.overflowBookmarkItem.MuiMenuItem-root.is-dragging-self{opacity:.4}.overflowBookmarkItem.MuiMenuItem-root.is-keyboard-reordering{outline:3px solid rgb(var(--button-bg-rgb));outline-offset:-3px}.overflowBookmarkItem.MuiMenuItem-root>.label-elements{overflow:hidden;min-width:0;flex:1 1 0px !important}.overflowBookmarkItem.MuiMenuItem-root>.label-elements>span{display:block;overflow:hidden;max-width:100%;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.overflowBookmarkItem.MuiMenuItem-root>.trailing-elements{flex-shrink:0;margin-inline-start:8px;opacity:0}.overflowBookmarkItem.MuiMenuItem-root:hover>.trailing-elements,.overflowBookmarkItem.MuiMenuItem-root.Mui-focusVisible>.trailing-elements,.overflowBookmarkItem.MuiMenuItem-root:has([aria-expanded=true])>.trailing-elements{opacity:1}

/*# sourceMappingURL=7888.f3ab86fd098415fb8f8d.css.map*/