.nav-pills__unread-indicator{position:absolute;z-index:2;display:flex;width:188px;height:auto;align-items:center;justify-content:center;padding:8px;border-radius:4px;margin-left:50%;background:var(--mention-bg);box-shadow:0 4px 6px rgba(0,0,0,.12);color:var(--mention-color);cursor:pointer;font-size:14px;font-weight:700;line-height:16px;opacity:0;text-align:center;transform:translateX(-50%);visibility:hidden}.nav-pills__unread-indicator .icon{display:inline-flex;align-items:center;justify-content:center;margin-right:8px}body.enable-animations .nav-pills__unread-indicator{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}.nav-pills__unread-indicator svg{fill:var(--mention-color)}.nav-pills__unread-indicator-top{top:16px}.nav-pills__unread-indicator-top .icon svg{transform:rotate(180deg)}.nav-pills__unread-indicator-bottom{bottom:16px}.nav-pills__unread-indicator--visible{opacity:1;visibility:visible}body.enable-animations .nav-pills__unread-indicator--visible{transition-delay:0s;transition-duration:.12s;transition-property:opacity,visibility;transition-timing-function:ease-out,step-start}@media screen and (max-width: 768px){.nav-pills__unread-indicator{width:260px}}@media screen and (max-width: 480px){.nav-pills__unread-indicator{width:230px}}@media screen and (max-width: 320px){.multi-teams .nav-pills__unread-indicator{width:190px}}

/*# sourceMappingURL=4986.5bd94826f9e4e54ef617.css.map*/