.file-preview-modal__info{display:flex;flex-direction:row;align-items:center;justify-content:flex-start}.file-preview-modal__info-details{display:flex;flex-direction:column;align-items:flex-start;margin-left:12px}.file-preview-modal__avatar.Avatar{width:40px;min-width:40px;height:40px;border-radius:50%}.file-preview-modal__file-name{overflow:hidden;max-width:30vw;margin:0;font-size:1.6rem;font-weight:600;line-height:24px;text-overflow:ellipsis;white-space:nowrap}.file-preview-modal__file-details{overflow:hidden;max-width:30vw;color:hsla(0,0%,100%,.75);font-size:1.4rem;font-weight:400;text-overflow:ellipsis;text-transform:capitalize;white-space:nowrap}.file-preview-modal__file-details-user-name{color:#fff}.file-preview-modal__user-name{margin:unset;font-size:1.6rem;font-weight:600;line-height:20px;text-transform:capitalize}.file-preview-modal__channel{margin-left:8px}@media screen and (max-width: 768px){.file-preview-modal__avatar.Avatar{width:32px;min-width:32px;height:32px;border-radius:50%}.file-preview-modal__channel{overflow:hidden;max-width:calc(100vw - 150px);margin-left:unset;text-overflow:ellipsis;white-space:nowrap}}
.file-preview-modal-main-actions__actions{z-index:999;display:flex;flex-direction:row;align-items:center;justify-content:flex-end}.file-preview-modal-main-actions__actions i{font-size:2.4rem}.file-preview-modal-main-actions__action-item{display:flex;overflow:hidden;width:40px;height:40px;align-items:center;justify-content:center;border:unset;border-radius:4px;margin-left:8px;background:rgba(0,0,0,0)}.file-preview-modal-main-actions__action-item:hover{background:hsla(0,0%,100%,.16)}.file-preview-modal-main-actions__action-item.active{background:hsla(0,0%,100%,.16)}.file-preview-modal-main-actions__action-item:first-child{margin-left:unset}
.file-preview-modal-footer{display:grid;width:100%;height:64px;align-items:center;justify-content:space-between;padding:8px 16px 8px 16px;background:#000;color:#fff;grid-template-columns:auto 1fr}
.file_preview_modal_main_nav{display:flex;align-items:center;justify-content:center;font-size:1.6rem;font-weight:600}.file_preview_modal_main_nav__next,.file_preview_modal_main_nav__prev{display:flex;overflow:hidden;width:40px;height:40px;align-items:center;justify-content:center;border:unset;border-radius:4px;margin-left:12px;background:rgba(0,0,0,0);font-weight:600}.file_preview_modal_main_nav__next:hover,.file_preview_modal_main_nav__prev:hover{background:hsla(0,0%,100%,.16)}.file_preview_modal_main_nav__next.active,.file_preview_modal_main_nav__prev.active{background:hsla(0,0%,100%,.16)}.file_preview_modal_main_nav__next i,.file_preview_modal_main_nav__prev i{font-size:2.4rem}.file_preview_modal_main_nav__prev{margin-right:12px;margin-left:unset}@media screen and (max-width: 768px){.file_preview_modal_main_nav{width:100%;margin-left:-24px}}
.file-preview-modal-header{position:relative;display:grid;width:100%;height:72px;align-items:center;justify-content:space-between;padding:16px;background:#000;color:#fff;grid-template-columns:1fr auto 1fr}@media screen and (max-width: 768px){.file-preview-modal-header{display:flex;height:44px;justify-content:flex-start;padding:8px}}
.image_preview__image{max-height:calc(100vh - 168px);border-radius:8px;cursor:default}@media screen and (max-width: 768px){.image_preview__image{border-radius:0}}
.file-preview-modal{padding-left:0 !important}.file-preview-modal__body{height:100vh;padding:0}.file-preview-modal__main-ctr{display:flex;width:100%;height:100%;flex-direction:column}.file-preview-modal__title{background:#000}.file-preview-modal__content{display:flex;height:calc(100vh - 72px);align-items:center;justify-content:center;padding:48px;background:rgba(0,0,0,.9)}@media screen and (max-width: 768px){.file-preview-modal__content{height:calc(100% - 108px);padding:0;background:#000}}.file-preview-modal__content-scrollable{padding:0}.file-preview-modal__scrollable{overflow:auto;width:100%;height:calc(100vh - 72px);padding:48px 5px 72px 0;margin:0 auto;margin-right:5px;scrollbar-color:hsla(0,0%,100%,.24) rgba(0,0,0,0);scrollbar-width:auto}.file-preview-modal__scrollable::-webkit-scrollbar-thumb{background:hsla(0,0%,100%,.24)}@media screen and (max-width: 768px){.file-preview-modal__scrollable{height:calc(100vh - 148px);padding:0}}.modal .modal-image .file-preview-modal__zoom-bar{background-color:rgba(61,60,64,.75)}.modal.fade .file-preview-modal{transform:translate(0, 0)}

/*# sourceMappingURL=11.5ada543d8439d319600a.css.map*/