"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[729],{60729:(e,t,o)=>{o.r(t),o.d(t,{default:()=>i});var n=o(37270),a=o(32446),s=o(79751),l=(o(15724),o(36418)),c=o.n(l);const i=(0,n.connect)((function(e){return{modals:e.views.modals}}),(function(e){return{actions:(0,a.zH)({closeModal:s.O},e)}}))((e=>{let{modals:t,actions:o}=e;if(!t)return null;const{modalState:n}=t,a=[];for(const e in n)if(Object.hasOwn(n,e)){const t=n[e];if(t.open){const n=c().createElement(t.dialogType,Object.assign({},t.dialogProps,{onExited:()=>{o.closeModal(e),t.dialogProps?.onExited?.()},onHide:o.closeModal.bind(void 0,e),key:`${e}_modal`}));a.push(n)}}return c().createElement(c().Fragment,null,a)}))}}]);
//# sourceMappingURL=729.253256552ee57082ea66.js.map