{{define "payment_failed_no_card_body"}}
<html>
<body>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="auto"
    style="margin-top: 20px; line-height: 1.7; color: #555;font-family: Arial; font-style: normal; font-weight: bold;">
    <tr>
        <td>
            <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%"
                style="max-width: 660px; font-family: Helvetica, Arial, sans-serif; font-size: 14px; background: #FFF;">
                <tr>
                    <td style="border: 1px solid #ddd;">
                        <table align="left" border="0" cellpadding="0" cellspacing="0" width="100%">
                            <tr>
                                <td style="padding: 20px 20px 10px; text-align:left;">
                                    <img src="{{.Props.SiteURL}}/static/images/logo-email.png" style="opacity: 0.5"
                                        width="130px" alt="">
                                </td>
                            </tr>
                        </table>
                        <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%"
                            style="border-collapse: collapse">
                            <tr>
                                <td>
                                    <table border="0" cellpadding="0" cellspacing="0"
                                        style="padding: 20px 0 0; text-align: center; margin: 0 auto; max-width: 443px">
                                        <tr>
                                            <td style="padding: 0 50px 64px;">
                                                <h2
                                                    style="margin-bottom: 0; text-align: center; color: #3D3C40; font-weight: bold; margin-top: 10px; line-height: 32px; font-size: 28px; font-family: Arial">
                                                    {{ .Props.Title }}</h2>
                                                <p
                                                    style="font-weight: normal; color: #3D3C40; font-size: 16px; line-height: 24px; font-family: Arial">
                                                    {{ .Props.Info1 }}</p>
                                                <p style="margin-top: 24px; margin-bottom: 24px; font-weight: normal; font-size: 16px; line-height: 24px; color: #3D3C40; font-family: Arial">{{.Props.Info3}}</p>
                                                <p style="margin: 31px 0 31px">
                                                    <a href="{{.Props.SiteURL}}/admin_console/billing/subscription"
                                                        target="_blank"
                                                        style="font-weight: normal; border-radius: 4px; background: #1C58D9; color: #fff;outline: none; min-width: 200px; padding: 11px 24px 11px 24px; font-size: 16px; font-family: Arial; cursor: pointer; -webkit-appearance: none;text-decoration: none; margin-top: 16px;">{{ .Props.Button }}</a>
                                                </p>
                                            </td>
                                        </tr>
                                    </table>
                                </td>
                            </tr>
                        </table>
                        <table align="center" border="0" cellpadding="0" cellspacing="0" max-width="612px">
                            <tr>
                                <td style="border-bottom: 1px solid #E5E5E5"></td>
                            </tr>
                        </table>
                        <table align="left" border="0" cellpadding="0" cellspacing="0" width="100%"
                            style="max-width: 443px; font-family: Helvetica, Arial, sans-serif; font-size: 14px; background: #FFF; border-collapse: collapse;">
                            <tr>
                                <td style="font-family: Arial; padding: 20px 20px 24px 48px; text-align:left;">
                                    <h3 style="margin-bottom: 0;">Questions?</h3>
                                    <p style="font-weight: normal; margin-top: 0;">{{ .Props.EmailUs }} <a
                                            href="mailto:feedback@mattermost.com">feedback@mattermost.com</a></p>
                                </td>
                            </tr>
                        </table>
                        <table align="center" border="0" cellpadding="0" cellspacing="0" max-width="612px">
                            <tr>
                                <td style="border-bottom: 1px solid #E5E5E5"></td>
                            </tr>
                        </table>
                        <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%"
                            style="font-family: Arial; line-height: 16px; font-size: 12px; background: #FFF;">
                            <tr>
                                <td
                                    style="font-weight: normal; text-align: center;color: #AAA;font-size: 11px;padding-bottom: 10px;padding: 0;line-height: 16px;padding-bottom: 48px;padding-top: 4px;">
                                    <p>
                                        {{.Props.Organization}}<br>
                                        {{.Props.Footer}}
                                    </p>
                                </td>

                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
</table>
</body>
</html>
{{end}}
