"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[7672],{7672:(a,e,t)=>{t.d(e,{default:()=>g});var n=t(36418),o=t.n(n),l=t(14778),s=t(37270),r=t(14696),i=t(52729),d=t(271),c=t(67416),m=t(78451),_=t(92008);const g=function(a){let{postId:e,onExited:t,onHide:n}=a;const g=(0,l.useIntl)(),u=(0,s.useSelector)((a=>(0,i.f5)(a,e)));if(!u)return null;const w=(0,_.AT)(u,g.locale),h=w?.source_lang||"unknown";return o().createElement(r.zW,{id:"showTranslationModal",className:"ShowTranslationModal a11y__modal",show:!0,onHide:()=>{n&&n()},onExited:t,ariaLabelledby:"showTranslationModalLabel",compassDesign:!0,modalHeaderText:g.formatMessage({id:"show_translation.modal.title",defaultMessage:"Show Translation"})},o().createElement("div",{className:"ShowTranslationModal__content"},o().createElement("div",{className:"ShowTranslationModal__messageBlock ShowTranslationModal__messageBlock--original"},o().createElement("div",{className:"ShowTranslationModal__badgeContainer"},o().createElement("span",{className:"ShowTranslationModal__languageText"},"unknown"===h?g.formatMessage({id:"show_translation.unknown_language",defaultMessage:"Unknown"}):g.formatDisplayName(h,{type:"language"})),o().createElement(c.A,{text:g.formatMessage({id:"show_translation.original_badge",defaultMessage:"ORIGINAL"}),variant:"info",size:"xs"})),o().createElement("div",{className:"ShowTranslationModal__postContent"},o().createElement(d.A,{post:u,isChannelAutotranslated:!1,location:m.Hc.MODAL,preventClickInteraction:!0}))),o().createElement("div",{className:"ShowTranslationModal__messageBlock ShowTranslationModal__messageBlock--translated"},o().createElement("div",{className:"ShowTranslationModal__badgeContainer"},o().createElement("span",{className:"ShowTranslationModal__languageText"},g.formatDisplayName(g.locale,{type:"language"})),o().createElement(c.A,{text:g.formatMessage({id:"show_translation.auto_translated_badge",defaultMessage:"AUTO-TRANSLATED"}),variant:"default",size:"xs"})),o().createElement("div",{className:"ShowTranslationModal__postContent"},o().createElement(d.A,{post:u,isChannelAutotranslated:!0,location:m.Hc.MODAL,preventClickInteraction:!0})))))}}}]);
//# sourceMappingURL=7672.c6aa2484dc470e8e1607.js.map