"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[5840],{75840:(e,n,t)=>{function i(e){return new RegExp(e.replace(/[-/\\^$*+?.()|[\]{}]/g,"\\$&"),"m")}function a(e){return e?"string"==typeof e?e:e.source:null}function o(e){return r("(?=",e,")")}function r(...e){return e.map((e=>a(e))).join("")}function s(...e){const n=function(e){const n=e[e.length-1];return"object"==typeof n&&n.constructor===Object?(e.splice(e.length-1,1),n):{}}(e);return"("+(n.capture?"":"?:")+e.map((e=>a(e))).join("|")+")"}function c(e){const n={scope:"keyword",match:/\b(yield|return|let|do|match|use)!/},t=["bool","byte","sbyte","int8","int16","int32","uint8","uint16","uint32","int","uint","int64","uint64","nativeint","unativeint","decimal","float","double","float32","single","char","string","unit","bigint","option","voption","list","array","seq","byref","exn","inref","nativeptr","obj","outref","voidptr","Result"],a={keyword:["abstract","and","as","assert","base","begin","class","default","delegate","do","done","downcast","downto","elif","else","end","exception","extern","finally","fixed","for","fun","function","global","if","in","inherit","inline","interface","internal","lazy","let","match","member","module","mutable","namespace","new","of","open","or","override","private","public","rec","return","static","struct","then","to","try","type","upcast","use","val","void","when","while","with","yield"],literal:["true","false","null","Some","None","Ok","Error","infinity","infinityf","nan","nanf"],built_in:["not","ref","raise","reraise","dict","readOnlyDict","set","get","enum","sizeof","typeof","typedefof","nameof","nullArg","invalidArg","invalidOp","id","fst","snd","ignore","lock","using","box","unbox","tryUnbox","printf","printfn","sprintf","eprintf","eprintfn","fprintf","fprintfn","failwith","failwithf"],"variable.constant":["__LINE__","__SOURCE_DIRECTORY__","__SOURCE_FILE__"]},c={variants:[e.COMMENT(/\(\*(?!\))/,/\*\)/,{contains:["self"]}),e.C_LINE_COMMENT_MODE]},l={scope:"variable",begin:/``/,end:/``/},u=/\B('|\^)/,p={scope:"symbol",variants:[{match:r(u,/``.*?``/)},{match:r(u,e.UNDERSCORE_IDENT_RE)}],relevance:0},f=function({includeEqual:e}){let n;n=e?"!%&*+-/<=>@^|~?":"!%&*+-/<>@^|~?";const t=r("[",...Array.from(n).map(i),"]"),a=s(t,/\./),c=r(a,o(a)),l=s(r(c,a,"*"),r(t,"+"));return{scope:"operator",match:s(l,/:\?>/,/:\?/,/:>/,/:=/,/::?/,/\$/),relevance:0}},d=f({includeEqual:!0}),b=f({includeEqual:!1}),m=function(n,i){return{begin:r(n,o(r(/\s*/,s(/\w/,/'/,/\^/,/#/,/``/,/\(/,/{\|/)))),beginScope:i,end:o(s(/\n/,/=/)),relevance:0,keywords:e.inherit(a,{type:t}),contains:[c,p,e.inherit(l,{scope:null}),b]}},g=m(/:/,"operator"),h=m(/\bof\b/,"keyword"),_={begin:[/(^|\s+)/,/type/,/\s+/,/[a-zA-Z_](\w|')*/],beginScope:{2:"keyword",4:"title.class"},end:o(/\(|=|$/),keywords:a,contains:[c,e.inherit(l,{scope:null}),p,{scope:"operator",match:/<|>/},g]},y={scope:"computation-expression",match:/\b[_a-z]\w*(?=\s*\{)/},E={begin:[/^\s*/,r(/#/,s("if","else","endif","line","nowarn","light","r","i","I","load","time","help","quit")),/\b/],beginScope:{2:"meta"},end:o(/\s|$/)},w={variants:[e.BINARY_NUMBER_MODE,e.C_NUMBER_MODE]},v={scope:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE]},A={scope:"string",begin:/@"/,end:/"/,contains:[{match:/""/},e.BACKSLASH_ESCAPE]},S={scope:"string",begin:/"""/,end:/"""/,relevance:2},C={scope:"subst",begin:/\{/,end:/\}/,keywords:a},k={scope:"string",begin:/\$"/,end:/"/,contains:[{match:/\{\{/},{match:/\}\}/},e.BACKSLASH_ESCAPE,C]},O={scope:"string",begin:/(\$@|@\$)"/,end:/"/,contains:[{match:/\{\{/},{match:/\}\}/},{match:/""/},e.BACKSLASH_ESCAPE,C]},R={scope:"string",begin:/\$"""/,end:/"""/,contains:[{match:/\{\{/},{match:/\}\}/},C],relevance:2},x={scope:"string",match:r(/'/,s(/[^\\']/,/\\(?:.|\d{3}|x[a-fA-F\d]{2}|u[a-fA-F\d]{4}|U[a-fA-F\d]{8})/),/'/)};return C.contains=[O,k,A,v,x,n,c,l,g,y,E,w,p,d],{name:"F#",aliases:["fs","f#"],keywords:a,illegal:/\/\*/,classNameAliases:{"computation-expression":"keyword"},contains:[n,{variants:[R,O,k,S,A,v,x]},c,l,_,{scope:"meta",begin:/\[</,end:/>\]/,relevance:2,contains:[l,S,A,v,x,w]},h,g,y,E,w,p,d]}}t.r(n),t.d(n,{default:()=>c})}}]);
//# sourceMappingURL=5840.2b213f95d5ea47e05ecf.js.map