"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[4602],{14602:(e,t,o)=>{o.r(t),o.d(t,{default:()=>f}),o(76281);var r=o(36418),a=o.n(r),l=o(14778),s=o(37270),c=o(26614),n=o(17518);const f=()=>{const{formatMessage:e}=(0,l.useIntl)(),{AboutLink:t,PrivacyPolicyLink:o,TermsOfServiceLink:r,HelpLink:f}=(0,s.useSelector)(c.zj);return document.cookie.includes("MMEMBED=1")?null:a().createElement("div",{className:"hfroute-footer"},a().createElement("span",{key:"footer-copyright",className:"footer-copyright"},`© ${(new Date).getFullYear()} Mattermost Inc.`),t&&a().createElement(n.A,{key:"footer-link-about",className:"footer-link",href:t,location:"footer"},e({id:"web.footer.about",defaultMessage:"About"})),o&&a().createElement(n.A,{key:"footer-link-privacy",className:"footer-link",href:o,location:"footer"},e({id:"web.footer.privacy",defaultMessage:"Privacy Policy"})),r&&a().createElement(n.A,{key:"footer-link-terms",className:"footer-link",href:r,location:"footer"},e({id:"web.footer.terms",defaultMessage:"Terms"})),f&&a().createElement(n.A,{key:"footer-link-help",className:"footer-link",href:f,location:"footer"},e({id:"web.footer.help",defaultMessage:"Help"})))}}}]);
//# sourceMappingURL=4602.85507b5c1340f4bbdca3.js.map