.LessThanMaxFreeUsers,.MoreThanMaxFreeUsers{display:flex;flex-direction:row}.LessThanMaxFreeUsers .titleAndButton,.MoreThanMaxFreeUsers .titleAndButton{display:flex;flex-direction:column;margin-left:20px}.LessThanMaxFreeUsers .titleAndButton>span,.MoreThanMaxFreeUsers .titleAndButton>span{margin-bottom:15px;font-size:16px;font-weight:600;line-height:24px}.MoreThanMaxFreeUsersWrapper{display:flex;flex-direction:row;gap:8px}
.hint-toast{display:flex;flex-wrap:nowrap;align-items:center;padding:4px 4px 4px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:0;background-color:var(--center-channel-bg);box-shadow:0 6px 14px rgba(0,0,0,.12);color:var(--center-channel-color);font-size:14px;font-weight:bold;gap:16px}.hint-toast .hint-toast__message{line-height:20px;text-align:center}.hint-toast .hint-toast__message .shortcut-key{font-weight:600}.hint-toast .hint-toast__dismiss{padding:4px}.hint-toast .hint-toast__dismiss:hover{background-color:var(--center-channel-bg)}.hint-toast .hint-toast__dismiss:hover svg{fill:rgba(var(--center-channel-color-rgb), 0.75)}.hint-toast .hint-toast__dismiss svg{fill:rgba(var(--center-channel-color-rgb), 0.75);vertical-align:middle}.hint-toast .hint-toast__dismiss .close-btn{cursor:pointer;line-height:normal}.hint-toast__wrapper{position:absolute;z-index:3;display:flex;width:100%;align-items:center;justify-content:center}
.scroll-to-bottom-toast{display:flex;align-items:center;justify-content:space-between;padding:4px;padding-left:12px;border-radius:4px;background-color:var(--button-bg);box-shadow:0 4px 6px 0 rgba(0,0,0,.12);color:var(--button-color-rgb);cursor:pointer;font-size:14px;font-weight:600;gap:8px}.scroll-to-bottom-toast:hover{background-color:rgba(var(--button-bg-rgb), 0.88)}.scroll-to-bottom-toast svg{fill:rgb(var(--button-color-rgb));vertical-align:middle}body.enable-animations .scroll-to-bottom-toast{transition-duration:0s;transition-property:opacity,visibility;transition-timing-function:ease-in-out}.scroll-to-bottom-toast .scroll-to-bottom-toast__message{display:inline-block;line-height:20px;vertical-align:middle}.scroll-to-bottom-toast .scroll-to-bottom-toast__message>svg{margin-right:8px}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss{display:inline-block;padding:4px;border-radius:4px}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss:hover{background-color:var(--button-bg)}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss svg{padding-top:1px;fill:rgba(var(--button-color-rgb), 0.64);vertical-align:middle}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss .close-btn{cursor:pointer;line-height:normal}.scroll-to-bottom-toast .scroll-to-bottom-toast__dismiss .close-btn:hover{fill:var(--button-color)}
.search-shortcut{display:inline-block;margin:0 4px}.search-shortcut .shortcut-key{margin-right:4px}.search-shortcut .shortcut-key:last-child{margin-right:0}
.toasts-wrapper{position:absolute;z-index:3;display:flex;width:calc(100% - 32px);align-items:center;justify-content:center;margin:16px 16px 0;gap:7px}
#teamMembersModal .GenericModal__header{display:flex;justify-content:center}
.DataGrid{width:100%;padding:2rem 2rem 2rem 2rem;background:#f5f5f5;color:var(--sys-center-channel-color)}.DataGrid .DataGrid_search{display:flex;height:48px;flex-direction:row;justify-content:space-between;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);background:#fff;font-weight:bold}.DataGrid .DataGrid_search .DataGrid_searchBar{position:relative;display:flex;width:300px;height:32px;box-sizing:border-box;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.2);border-radius:4px;margin-left:8px}.DataGrid .DataGrid_search .DataGrid_searchBar input{width:100%;border:0;margin-right:16px;margin-left:32px;font-size:.95em}.DataGrid .DataGrid_search .DataGrid_searchBar input:focus{outline:none}.DataGrid .DataGrid_search .DataGrid_searchBar .DataGrid_searchIcon{position:absolute;top:5px;left:10px;color:rgba(0,0,0,.5);pointer-events:none}.DataGrid .DataGrid_search .DataGrid_searchBar .DataGrid_clearButton{display:flex;align-items:center;margin-right:5px}.DataGrid .DataGrid_header{display:flex;flex-direction:row;padding:.5em 0;border-bottom:solid 1px rgba(0,0,0,.1);color:rgba(0,0,0,.87);font-size:1.1em;font-weight:bold}.DataGrid .DataGrid_rows{display:flex;flex-direction:column;background:rgba(var(--sys-button-color-rgb), 0.5)}.DataGrid .DataGrid_rows .DataGrid_loading{padding-top:20px;padding-bottom:20px;margin:auto;color:rgba(0,0,0,.3);font-size:1.6rem}.DataGrid .DataGrid_rows .DataGrid_empty{width:100%;padding-top:20px;padding-bottom:20px;color:rgba(0,0,0,.3);font-size:1.6rem;text-align:center}.DataGrid .DataGrid_rows .DataGrid_row{border-left:2px solid rgba(0,0,0,0)}.DataGrid .DataGrid_rows .DataGrid_row:nth-child(odd){background-color:#f5f5f5}.DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:2px solid #166de0;background-color:rgb(223.5853658537,235.7865853659,251.9146341463)}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell{overflow:hidden;margin:auto;text-overflow:ellipsis;white-space:nowrap}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions{color:rgba(61,60,64,.75)}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions .shared-user-icon{width:16px;height:16px;margin-left:8px;font-size:16px;line-height:16px}.DataGrid .DataGrid_rows .DataGrid_row .DataGrid_cell .more-modal__shared-actions .shared-user-icon::before{margin:0}.DataGrid .DataGrid_row,.DataGrid .DataGrid_header{display:flex;height:auto;flex-direction:row;padding-left:18px}.DataGrid .DataGrid_row .DataGrid_cell,.DataGrid .DataGrid_header .DataGrid_cell{flex:1 0}.DataGrid .DataGrid_footer{display:flex;height:auto;flex-direction:row;padding:8px;border-top:solid 1px rgba(0,0,0,.1);border-bottom:solid 1px rgba(0,0,0,.1);background:#fff;color:rgba(0,0,0,.5);font-size:1.1em;text-align:right}.DataGrid .DataGrid_footer .DataGrid_cell{width:100%;text-align:right}.DataGrid.customTable{padding:0;background:#fff}.DataGrid.customTable .DataGrid_header{padding:8px 0;border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);color:var(--sys-center-channel-color);font-size:14px;font-weight:600;line-height:16px}.DataGrid.customTable .DataGrid_header:last-child{border-bottom:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08)}.DataGrid.customTable .DataGrid_header .DataGrid_cell{padding:0 16px}.DataGrid.customTable .DataGrid_row{display:flex;min-height:40px;flex-direction:row;padding:0;border-left:none}.DataGrid.customTable .DataGrid_row:nth-child(odd){background:#fff}.DataGrid.customTable .DataGrid_row:nth-child(even){background:rgba(var(--sys-button-bg-rgb), 0.04)}.DataGrid.customTable .DataGrid_row:hover{border-left:none;background-color:rgba(var(--sys-button-bg-rgb), 0.08);color:var(--sys-center-channel-color);cursor:pointer}.DataGrid.customTable .DataGrid_row .actionIcon{width:32px}.DataGrid.customTable .DataGrid_row .actionIcon .MenuWrapper{width:32px;margin-left:auto}.DataGrid.customTable .DataGrid_row .actionIcon a i{display:none}.DataGrid.customTable .DataGrid_row .actionIcon a{display:flex;width:32px;height:32px;flex-direction:column;align-items:center;padding:8px;border-radius:4px;margin-left:auto;background:rgba(0,0,0,0);color:rgba(var(--sys-center-channel-color-rgb), 0.75);text-decoration:none}.DataGrid.customTable .DataGrid_row:hover .actionIcon a i{display:flex}.DataGrid.customTable .DataGrid_row .actionIcon a:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.DataGrid.customTable .DataGrid_row .DataGrid_cell{padding:10px 16px;margin:0;white-space:normal}.DataGrid.customTable .DataGrid_row .DataGrid_cell.actionIcon{overflow:visible;padding:4px 16px}.DataGrid.customTable .DataGrid_footer{border-bottom:none}
.Filter{position:relative;display:inline-block;padding-left:8px}.Filter .Filter_button{width:auto;height:32px;padding:0 10px;border:0;border-radius:4px;background:var(--sys-center-channel-bg);color:var(--sys-button-bg);font-size:12px}.Filter .Filter_button.Filter__active,.Filter .Filter_button:focus{background:rgba(var(--sys-button-bg-rgb), 0.12)}.Filter .Filter_button:hover{background:rgba(var(--sys-button-bg-rgb), 0.06)}.Filter .Icon{margin-right:2px;font-size:14px}.Filter .Filter_content{position:absolute;z-index:1;display:none;min-width:256px;box-sizing:border-box;padding:16px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.08);border-radius:4px;margin-top:4px;margin-bottom:24px;background:var(--sys-center-channel-bg);box-shadow:0 8px 24px rgba(0,0,0,.12)}.Filter .Filter_content.Filter__show{display:block}.Filter .Filter_content hr{padding:0;margin:8px -16px 8px -16px;color:rgba(var(--sys-center-channel-color-rgb), 0.08)}.Filter .Filter_header{display:flex;flex-direction:row;justify-content:space-between}.Filter .Filter_header .Filter_title{padding:8px;color:var(--sys-center-channel-color);font-size:14px;font-weight:bold;line-height:14px}.Filter .Filter_header .Filter_reset{padding:8px;font-size:12px;line-height:16px}.Filter .Filter_lists{white-space:nowrap}.Filter .Filter_apply{float:right}.Filter .FilterList{display:inline-block;width:160px;padding:8px;font-size:14px;vertical-align:top}.Filter .FilterList.FilterList__full{display:block;width:100%}.Filter .FilterList .FilterList_name{padding-bottom:12px;color:rgba(var(--sys-center-channel-color-rgb), 0.5);font-size:12px;font-weight:600}.Filter .FilterList .filterListSelect__control{min-height:32px;border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.16);border-radius:4px;background:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.75);font-size:12px}.Filter .FilterList .filterListSelect__control:hover{border:1px solid rgba(var(--sys-center-channel-color-rgb), 0.48)}.Filter .FilterList .filterListSelect__option{background:var(--sys-center-channel-bg);color:rgba(var(--sys-center-channel-color-rgb), 0.8);cursor:pointer;font-size:12px}.Filter .FilterList .filterListSelect__option:hover{background:rgba(var(--sys-center-channel-color-rgb), 0.08)}.Filter .FilterList .filterListSelect__indicator{padding:9px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);cursor:pointer}.Filter .FilterList .filterListSelect__indicator>svg{width:14px;height:14px}.Filter .FilterList .filterListSelect__indicator-separator{background-color:rgba(var(--sys-center-channel-color-rgb), 0.16)}.Filter .FilterList .filterListSelect__multi-value__remove:hover{background-color:rgba(var(--center-channel-color-rgb), 0.16);color:inherit;cursor:pointer}.Filter .FilterList .FilterList_checkbox{color:rgba(var(--sys-center-channel-color-rgb), 0.8)}.Filter .FilterList .FilterList_checkbox input{position:relative;top:-4px;margin:0 8px 0 2px;opacity:.73;vertical-align:bottom}.Filter .FilterList .FilterList_checkbox input:checked{opacity:1}.Filter .FilterList .FilterList_checkbox label{font-weight:normal}
.PolicyTable{overflow:auto}.PolicyTable .DataGrid{padding:0;background-color:rgba(var(--sys-white-rgb), 0.04)}.PolicyTable .DataGrid_search{height:4em;border-bottom:none}.PolicyTable .DataGrid_searchBar{margin-left:0 !important}.PolicyTable .DataGrid_header{padding-left:12px;font-size:1em;font-weight:600}.PolicyTable .DataGrid_header .DataGrid_cell{display:flex}.PolicyTable .DataGrid_header .DataGrid_cell[data-field=name]{justify-content:flex-start}.PolicyTable .DataGrid_header .DataGrid_cell[data-field=resources]{display:flex;align-items:left;justify-content:flex-start}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row{display:flex;min-height:40px;padding-left:12px !important;border-left:none;background-color:rgba(var(--sys-white-rgb), 0.04);cursor:pointer}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:none;background-color:rgba(0,0,0,.05)}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-name{width:100%;padding:10px 0}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-resources{width:100%;padding:10px 0;text-align:left}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-actions{display:flex;width:100%;justify-content:flex-end;padding-right:8px}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-menu-button{display:flex;width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-menu-button:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.PolicyTable .DataGrid .DataGrid_rows .DataGrid_row .policy-menu-button .icon{display:flex;align-items:center;justify-content:center;font-size:18px;line-height:18px}.PolicyTable .DataGrid_footer{border-bottom:0}.PolicyTable .policy-header{display:flex;align-items:center;justify-content:space-between;margin-bottom:16px}.PolicyTable .policy-header-text h1{margin-bottom:8px;font-size:20px;font-weight:600}.PolicyTable .policy-header-text p{margin:0;color:rgba(63,67,80,.72)}.PolicyTable .policy-header .btn-primary{display:flex;align-items:center;padding:10px 16px;gap:8px}.PolicyTable .policy-header .btn-primary .icon{font-size:18px}.PolicyTable .action-wrapper{display:flex;justify-content:flex-end;padding:0 16px}.PolicyTable .action-wrapper .icon-button{display:flex;width:32px;height:32px;align-items:center;justify-content:center;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(63,67,80,.72);cursor:pointer}.PolicyTable .action-wrapper .icon-button:hover{background-color:rgba(63,67,80,.08);color:rgba(63,67,80,.8)}.PolicyTable .action-wrapper .icon-button .icon{font-size:18px}.policy-refresh-btn{display:flex;width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer;font-size:18px;outline:none}.policy-refresh-btn:focus-visible{border-radius:4px;outline:2px solid var(--button-bg);outline-offset:2px}.policy-refresh-btn:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.policy-refresh-btn:active{background-color:rgba(var(--center-channel-color-rgb), 0.16)}.actions-column{justify-content:flex-end !important;text-align:right}.PolicyList__no-results{display:flex;flex-direction:column;align-items:center;padding:48px 0;color:rgba(var(--center-channel-color-rgb), 0.48);font-size:18px;font-weight:600;text-align:center}.PolicyList__no-results-hint{margin-top:8px;font-size:14px;font-weight:400}
.SyncStatusFooter{display:flex;align-items:center;padding:0;margin-top:-34px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:14px;gap:4px}.SyncStatusFooter__icon{font-size:16px}.SyncStatusFooter__text{margin-right:2px}.SyncStatusFooter__link{color:var(--button-bg);font-size:12px;font-weight:600}.SyncStatusFooter__link:hover{text-decoration:underline}.SyncStatusFooter__syncing{color:rgba(var(--center-channel-color-rgb), 0.48);font-style:italic}
.AccessControlPolicyChannelsList .Filter_content.Filter__show{width:320px}.AccessControlPolicyChannelsList .FilterList{width:auto}.AccessControlPolicyChannelsList .ChannelList__nameColumn{display:inline-flex;align-items:center}.AccessControlPolicyChannelsList .ChannelList__nameColumn span.channel-icon{margin-right:8px}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader{display:flex;align-items:center;justify-content:flex-start;padding-left:16px;gap:8px}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox{position:relative;display:inline-block;width:16px;height:16px;padding:0;border:1px solid var(--center-channel-color);border-radius:2px;appearance:none;background:none;cursor:pointer;transition:all .15s ease}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox>*{pointer-events:none}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:checked{border:0;background-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:checked::after{position:absolute;top:1px;left:5px;width:6px;height:10px;border:solid #fff;border-width:0 1.5px 1.5px 0;content:"";transform:rotate(45deg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:indeterminate{border:0;background-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:indeterminate::after{position:absolute;top:7px;left:3px;width:10px;height:2px;background-color:#fff;content:""}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:focus{box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.2);outline:none}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:hover:not(:disabled){border-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-checkbox:disabled{border-color:rgba(var(--sys-center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.48}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .header-text{letter-spacing:.02em}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .ChannelList__autoAddInfoIcon{margin-left:-6px;color:rgba(var(--sys-center-channel-color-rgb), 0.56);font-size:16px}.AccessControlPolicyChannelsList .ChannelList__autoAddHeader .ChannelList__autoAddInfoIcon:hover{color:rgba(var(--sys-center-channel-color-rgb), 0.72)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn{display:flex;align-items:center;justify-content:flex-start;padding-left:16px;gap:8px}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox{position:relative;display:inline-block;width:16px;height:16px;padding:0;border:1px solid var(--center-channel-color);border-radius:2px;appearance:none;background:none;cursor:pointer;transition:all .15s ease}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox>*{pointer-events:none}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:checked{border:0;background-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:checked::after{position:absolute;top:1px;left:5px;width:6px;height:10px;border:solid #fff;border-width:0 1.5px 1.5px 0;content:"";transform:rotate(45deg)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:focus{box-shadow:0 0 0 2px rgba(var(--button-bg-rgb), 0.2);outline:none}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:hover:not(:disabled){border-color:var(--button-bg)}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .channel-checkbox:disabled{border-color:rgba(var(--sys-center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.48}.AccessControlPolicyChannelsList .ChannelList__autoAddColumn .checkbox-label{line-height:16px;user-select:none}.AccessControlPolicyChannelsList .DataGrid{padding:0;background-color:rgba(var(--sys-white-rgb), 0.04)}.AccessControlPolicyChannelsList .DataGrid_search{border-bottom:none}.AccessControlPolicyChannelsList .DataGrid_searchBar{margin-left:0}.AccessControlPolicyChannelsList .DataGrid .DataGrid_rows .DataGrid_row{display:flex;min-height:40px;border-left:none;background-color:rgba(var(--sys-white-rgb), 0.04);cursor:pointer}.AccessControlPolicyChannelsList .DataGrid .DataGrid_rows .DataGrid_row:hover{border-left:none;background-color:rgba(0,0,0,.05)}
.app__body .modal .channel-selector-modal .modal-header .GenericModal__header__text_container,.console__body .modal .channel-selector-modal .modal-header .GenericModal__header__text_container{margin-top:0}
.TeamPolicyConfirmationModal .modal-body{padding:0 24px 24px}.TeamPolicyConfirmationModal__body p{margin:0 0 16px;color:rgba(var(--center-channel-color-rgb), 0.72);font-size:14px;line-height:20px}.TeamPolicyConfirmationModal__body p:last-child{margin-bottom:0}.TeamPolicyConfirmationModal__footer{display:flex;justify-content:flex-end;gap:8px}
.TeamPolicyEditor{padding-bottom:80px;margin-top:-8px}.TeamPolicyEditor__masked-values-warning{margin-bottom:16px}.TeamPolicyEditor__header{margin-bottom:0}.TeamPolicyEditor__back-btn{display:flex;align-items:center;color:var(--center-channel-color);cursor:pointer;font-family:"Metropolis",sans-serif;font-size:16px;font-weight:600;gap:8px;line-height:24px}.TeamPolicyEditor__back-btn .fa{font-size:20px}.TeamPolicyEditor__divider{border:none;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:20px 0}.TeamPolicyEditor__divider--full-width{margin-right:-32px;margin-left:-32px}.TeamPolicyEditor__divider.header-divider{margin-top:12px}.TeamPolicyEditor__name-input{margin-bottom:0}.TeamPolicyEditor__name-hint{margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:12px;line-height:16px}.TeamPolicyEditor__name-hint--error{color:var(--error-text)}.TeamPolicyEditor__section{margin-bottom:0}.TeamPolicyEditor__mixed-channels-notice{margin-top:16px}.TeamPolicyEditor__mixed-channels-notice h4{margin-bottom:0}.TeamPolicyEditor__section-header{display:flex;align-items:flex-start;justify-content:space-between;margin-bottom:16px}.TeamPolicyEditor__section-title{margin:0 0 4px;color:var(--center-channel-color);font-size:16px;font-weight:600;line-height:24px}.TeamPolicyEditor__section-subtitle{margin:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-size:14px;line-height:20px}.TeamPolicyEditor .table-editor__cell button{color:var(--center-channel-color) !important}.TeamPolicyEditor .table-editor__cell button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08) !important}.TeamPolicyEditor .editor__help-text{width:75%;color:rgba(var(--center-channel-color-rgb), 0.56) !important}.TeamPolicyEditor__delete-modal-footer{display:flex;justify-content:flex-end;gap:8px}
.TeamAccessPoliciesTab__header{display:flex;align-items:center;justify-content:space-between;margin-bottom:16px}.TeamAccessPoliciesTab__title{margin:0;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:16px;font-weight:600;line-height:24px}.TeamAccessPoliciesTab__add-btn{display:flex;align-items:center;padding:6px 16px;font-size:13px;gap:4px}.TeamAccessPoliciesTab__add-btn .icon{font-size:16px}.TeamAccessPoliciesTab .PolicyTable .DataGrid{background-color:var(--center-channel-bg)}.TeamAccessPoliciesTab .PolicyTable .DataGrid_search{background:var(--center-channel-bg)}.TeamAccessPoliciesTab .PolicyTable .DataGrid_search .DataGrid_searchBar{border-color:rgba(var(--center-channel-color-rgb), 0.2)}.TeamAccessPoliciesTab .PolicyTable .DataGrid_search .DataGrid_searchBar input{background:var(--center-channel-bg);color:var(--center-channel-color)}.TeamAccessPoliciesTab .PolicyTable .DataGrid_search .DataGrid_searchBar .DataGrid_searchIcon{color:rgba(var(--center-channel-color-rgb), 0.5)}.TeamAccessPoliciesTab .PolicyTable .DataGrid_header{border-bottom-color:rgba(var(--center-channel-color-rgb), 0.16);color:var(--center-channel-color)}.TeamAccessPoliciesTab .PolicyTable .DataGrid .DataGrid_rows{background:var(--center-channel-bg)}.TeamAccessPoliciesTab .PolicyTable .DataGrid .DataGrid_rows .DataGrid_row{background-color:var(--center-channel-bg);color:var(--center-channel-color)}.TeamAccessPoliciesTab .PolicyTable .DataGrid .DataGrid_rows .DataGrid_row:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.TeamAccessPoliciesTab .PolicyTable .DataGrid_footer{background:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.5)}.TeamAccessPoliciesTab .PolicyTable .action-wrapper .icon-button{color:rgba(var(--center-channel-color-rgb), 0.72)}.TeamAccessPoliciesTab .PolicyTable .action-wrapper .icon-button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8)}.TeamAccessPoliciesTab .DataGrid.customTable{background:var(--center-channel-bg)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_search{background:var(--center-channel-bg)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_search .DataGrid_searchBar{border-color:rgba(var(--center-channel-color-rgb), 0.2)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_search .DataGrid_searchBar input{background:var(--center-channel-bg);color:var(--center-channel-color)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_search .DataGrid_searchBar .DataGrid_searchIcon{color:rgba(var(--center-channel-color-rgb), 0.5)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_rows{background:var(--center-channel-bg)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_header{border-bottom-color:rgba(var(--center-channel-color-rgb), 0.16);color:var(--center-channel-color)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_row{color:var(--center-channel-color)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_row:nth-child(odd){background:var(--center-channel-bg)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_row:nth-child(even){background:rgba(var(--button-bg-rgb), 0.04)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_row:hover{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_row .actionIcon a{color:rgba(var(--center-channel-color-rgb), 0.75)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_row .actionIcon a:hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.TeamAccessPoliciesTab .DataGrid.customTable .DataGrid_footer{background:var(--center-channel-bg);color:rgba(var(--center-channel-color-rgb), 0.5)}
.select-text-description{margin-top:8px;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:Open Sans;font-size:12px;font-style:normal;font-weight:400;line-height:16px}
.modal-access-tab-content .divider-light{margin:24px 0}.modal-access-tab-content .mm-modal-generic-section-item__content{margin-top:24px}.modal-access-tab-content #allowedDomains{margin-top:16px}.modal-access-tab-content .access-invite-section{gap:0}.modal-access-tab-content .access-invite-section #teamInviteContainer{display:flex;align-items:center}.modal-access-tab-content .access-invite-section #teamInviteContainer .Input_container{margin-right:8px}.modal-access-tab-content .access-invite-section #teamInviteContainer .Input_container #teamInviteId{background-color:unset}.modal-header{background-color:var(--center-channel-bg)}
.picture-setting-item{flex:1;margin-left:40px}.picture-setting-item__remove-button{display:flex;align-items:center;margin-top:18px;color:var(--dnd-indicator);text-align:left}.picture-setting-item__remove-button svg{margin-right:6px}.picture-setting-item .team-picture-section{position:relative;width:fit-content}.picture-setting-item .team-picture-section__team-icon{display:flex;width:120px;height:120px;align-items:center;justify-content:center;border-radius:24px;background-color:var(--sidebar-header-bg);cursor:pointer}.picture-setting-item .team-picture-section__team-name{color:var(--sidebar-header-text-color);font-family:Metropolis;font-size:56px;font-style:normal;font-weight:600;line-height:56px;text-align:center}.picture-setting-item .team-picture-section .icon-pencil-outline{position:absolute;right:-6px;bottom:-6px;padding:4px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:20px;background:var(--center-channel-bg, #fff);box-shadow:0 2px 3px 0 var(--elevation-1);cursor:pointer}.picture-setting-item .team-picture-section .team-img-preview{width:120px;height:120px;border-radius:24px;cursor:pointer}
.modal-info-tab-content{display:flex}.modal-info-tab-content .name-description-container{flex:2}.modal-info-tab-content .description-section-input .Input_fieldset{height:100%}.modal-info-tab-content #teamName,.modal-info-tab-content #teamDescription{background-color:unset}.modal-info-tab-content .description-setting-item{margin-top:24px}.modal-header{background-color:var(--center-channel-bg)}
.TeamSettingsModal{width:min(1024px,100vw - 32px) !important}.TeamSettingsModal .GenericModal__wrapper{display:flex;overflow:visible;max-width:1200px;max-height:90vh;flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.TeamSettingsModal .GenericModal__wrapper .modal-body{display:flex;width:auto;min-height:150px;flex-direction:column;margin:0;gap:24px;overflow-y:auto}.TeamSettingsModal__bodyWrapper{display:flex;width:100%;max-width:1024px;flex-direction:column;gap:24px}.TeamSettingsModal .settings-table{display:flex;flex-direction:row}.TeamSettingsModal .settings-table .settings-content{display:flex;overflow:visible !important;flex:1;flex-direction:column;padding:0 32px}.TeamSettingsModal .modal-body .form-control{border:none !important}.TeamSettingsModal .SaveChangesPanel{width:70%}@media screen and (max-width: 768px){.TeamSettingsModal .SaveChangesPanel{width:60%}}@media screen and (max-width: 768px){.TeamSettingsModal{max-width:100%;margin:0}.TeamSettingsModal .modal-content{display:flex;height:100vh;max-height:unset;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.TeamSettingsModal .modal-content{max-height:90vh}}@media screen and (max-height: 600px){.TeamSettingsModal .modal-content,.TeamSettingsModal .GenericModal__wrapper{max-height:85vh !important}}
.sidebarHeaderContainer{display:flex;height:55px;flex-direction:row;flex-wrap:nowrap;align-items:center;justify-content:space-between;padding:0 16px;color:var(--sidebar-header-text-color)}.sidebarHeaderContainer button#sidebarTeamMenuButton{overflow:hidden;padding:2px 6px;color:inherit;font-family:Metropolis,sans-serif;font-size:16px;gap:1px}.sidebarHeaderContainer button#sidebarTeamMenuButton:hover{background:rgba(var(--sidebar-header-text-color-rgb), 0.08)}.sidebarHeaderContainer button#sidebarTeamMenuButton:active,.sidebarHeaderContainer button#sidebarTeamMenuButton[aria-expanded=true][aria-haspopup=true]{background:rgba(var(--sidebar-header-text-color-rgb), 0.12)}.sidebarHeaderContainer button#sidebarTeamMenuButton>span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.sidebarHeaderContainer button#sidebarTeamMenuButton>.icon{display:flex;justify-content:center}#sidebarTeamMenu .learnAboutTeamsMenuItem .leading-element,#sidebarTeamMenu .learnAboutTeamsMenuItem .label-elements>span{color:var(--link-color)}
.mark_all_as_read_modal{width:512px}.mark_all_as_read_modal .modal-body{margin-bottom:48px}.mark_all_as_read_modal .modal-header{min-height:56px;padding-bottom:0}.mark_all_as_read_modal__body{display:flex;flex-direction:column;justify-content:center;padding:0 48px 32px;text-align:center}.mark_all_as_read_modal__body h2{margin-top:0;font-size:22px;font-weight:600}.mark_all_as_read_modal__body mark+mark{margin-left:4px}.mark_all_as_read_modal__body .checkbox{margin-top:16px}.mark_all_as_read_modal__footer{display:flex;justify-content:center;gap:10px}
#browseChannelsModal .modal-content{width:100%}@media screen and (max-width: 640px){#browseChannelsModal .modal-dialog{width:100%;max-width:100%;margin-top:0 !important}}@media screen and (max-width: 640px){#browseChannelsModal .modal-content{overflow:hidden}}#browseChannelsModal .filter-row{position:relative;padding:0 32px}#browseChannelsModal .filter-row .input-clear{top:16px;right:14px}#browseChannelsModal .filter-row #searchIcon{position:absolute;z-index:2;top:16px;left:42px;color:rgba(var(--center-channel-color-rgb), 0.64);pointer-events:none}#browseChannelsModal .filter-row #searchChannelsTextbox{height:48px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:none;font-size:16px;padding-inline:40px}#browseChannelsModal .filter-row #searchChannelsTextbox::placeholder{color:var(--center-channel-color)}#browseChannelsModal .filter-row #searchChannelsTextbox:focus{border:2px solid var(--button-bg)}#browseChannelsModal .more-modal__dropdown{display:flex;align-items:center;justify-content:space-between;padding:8px 32px;border-bottom:solid 1px rgba(var(--center-channel-color-rgb), 0.16);margin:0}#browseChannelsModal .more-modal__dropdown span{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}#browseChannelsModal .more-modal__dropdown #channelCountLabel{color:var(--center-channel-color);font-size:12px;font-weight:400}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer{display:flex;align-items:center;justify-content:center}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox{position:relative;display:flex;width:16px;height:16px;align-items:center;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:var(--radius-xs);margin-right:6px;background-color:var(--center-channel-bg)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox.checked{border:none}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer .get-app__checkbox svg{position:absolute;top:0;left:0;width:16px;height:16px;fill:var(--button-bg)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #hideJoinedPreferenceCheckbox{display:flex;align-items:center;cursor:pointer}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper{display:flex;align-items:center;justify-content:center;padding:4px 6px 4px 8px;border:none;margin-right:10px;background-color:unset}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper[aria-expanded=true]{border-radius:4px;background-color:rgba(var(--button-bg-rgb), 0.12)}#browseChannelsModal .more-modal__dropdown #modalPreferenceContainer #menuWrapper:hover{border-radius:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08)}#browseChannelsModal .modal-body{padding:0}#browseChannelsModal .modal-body .filtered-user-list{height:500px}#browseChannelsModal .modal-body .more-modal__row{padding:0 32px;border-bottom:none}#browseChannelsModal .modal-body .more-modal__row .more-modal__details{overflow:hidden;min-width:0;padding-left:0;color:rgba(var(--center-channel-color-rgb), 0.75)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details svg{flex-shrink:0}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .more-modal__name{align-items:center;margin-top:0}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .more-modal__name span{color:var(--center-channel-color);font-weight:500}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer{display:flex;align-items:center;justify-content:flex-start}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer .dot{width:3px;height:3px;flex-shrink:0;border-radius:50%;background-color:rgba(var(--center-channel-color-rgb), 0.75)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer .more-modal__description{overflow:hidden;margin-left:4px;font-weight:400;text-overflow:ellipsis;white-space:nowrap}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer{display:flex;align-items:center}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer span,#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer #membershipIndicatorContainer svg{color:var(--online-indicator)}#browseChannelsModal .modal-body .more-modal__row .more-modal__details #channelPurposeContainer span{margin:0 4px;font-size:12px;font-weight:600;line-height:12px;opacity:1}#browseChannelsModal .modal-body .more-modal__row .more-modal__details .shared-channel-icon{width:18px;height:18px;margin-right:6px;color:rgba(61,60,64,.75);font-size:18px;line-height:18px}#browseChannelsModal .modal-body .more-modal__row .more-modal__actions button{min-width:54px;height:32px;font-size:12px;font-weight:600;transition:background-color .15s ease,border-color .15s ease,color .15s ease,box-shadow .15s ease;visibility:hidden}#browseChannelsModal .modal-body .more-modal__row:hover,#browseChannelsModal .modal-body .more-modal__row:focus{background-color:rgba(var(--center-channel-color-rgb), 0.08);cursor:pointer}#browseChannelsModal .modal-body .more-modal__row:hover .more-modal__actions .primaryButton,#browseChannelsModal .modal-body .more-modal__row:hover .more-modal__actions .outlineButton,#browseChannelsModal .modal-body .more-modal__row:focus .more-modal__actions .primaryButton,#browseChannelsModal .modal-body .more-modal__row:focus .more-modal__actions .outlineButton{visibility:visible}#browseChannelsModal .modal-body .form-group{padding:0 32px;margin-bottom:0}#browseChannelsModal .modal-body ::-webkit-scrollbar{width:4px}#browseChannelsModal .modal-body ::-webkit-scrollbar-track{background:none}#browseChannelsModal .modal-header .GenericModal__header{display:flex;width:100%;align-items:center;justify-content:space-between;padding-right:4px}#browseChannelsModal .filter-controls{padding-top:24px}#moreChannelsList .primary-message{margin-top:8px;color:var(--center-channel-color);line-height:28px;word-wrap:break-word}#moreChannelsList .secondary-message{margin-bottom:30px}#browseChannelsDropdown .label-elements{padding:2px 4px;font-size:14px;line-height:20px}
#SidebarContainer .SidebarChannel .SidebarLink .channel-pencil-icon{position:relative;display:flex;width:28px;min-width:0;flex:0 0 28px;align-items:center;justify-content:center;padding:0;margin:0;font-size:14px;line-height:18px}
body.app__body.popout #root .main-wrapper.channel-popout{border:none;margin:0;background-color:var(--center-channel-bg);grid-template:"center rhs";grid-template-columns:1fr min-content}body.app__body.popout #root .main-wrapper.channel-popout #channel_view{overflow:hidden;grid-area:center}body.app__body.popout #root .main-wrapper.channel-popout .sidebar--right--width-holder{grid-area:rhs}body.app__body.popout #root .main-wrapper.channel-popout #sidebar-right{top:0;right:0}body.app__body.popout #root .main-wrapper.channel-popout .post-right__container .PopoutButton{display:initial}@media screen and (max-width: 768px){body.app__body.popout #root .main-wrapper.channel-popout{grid-template:"main";grid-template-columns:1fr}body.app__body.popout #root .main-wrapper.channel-popout #channel_view,body.app__body.popout #root .main-wrapper.channel-popout #sidebar-right{grid-area:main}body.app__body.popout #root .main-wrapper.channel-popout .sidebar--right--width-holder{display:none}body.app__body.popout #root .main-wrapper.channel-popout:not(.rhs-open) #channel-header{display:flex}body.app__body.popout #root .main-wrapper.channel-popout:not(.rhs-open) #channel-header .flex-parent{width:100%}body.app__body.popout #root .main-wrapper.channel-popout .channel-header .channel-header__icon{display:flex}body.app__body.popout #root .main-wrapper.channel-popout .channel__wrap .app__content{padding-top:0}body.app__body.popout #root .main-wrapper.channel-popout .search-bar__container{display:none !important}body.app__body.popout #root .main-wrapper.channel-popout .sidebar--right__close{display:block}}
.ChannelMoveToSubMenu__disabledContainer+hr{margin-top:8px;margin-bottom:8px}

/*# sourceMappingURL=5064.91c0b8b8b9fcfb72489d.css.map*/