@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.sidebar--menu{position:absolute;right:0;overflow:auto;width:290px;height:100%;padding:0 0 2em;border-right:1px solid rgba(var(--center-channel-color-rgb), 0.12);background:var(--sidebar-bg);color:rgba(var(--sidebar-text-rgb), 0.8);-webkit-overflow-scrolling:touch;transform:translate3d(290px, 0, 0);transition:transform .3s linear}.sidebar--menu.move--left{transform:translate3d(0, 0, 0)}.sidebar--menu .a11y--focused{box-shadow:rgba(56,111,229,.5) 0px 0px 1px 3px,#386fe5 0px 0px 0px 1px !important}.sidebar--menu .mentions{font-size:17px;font-weight:bold}.sidebar--menu .Menu .MenuItem.MenuItem--with-icon .MenuItem__help-text{padding-left:0}.sidebar--menu .icon{display:inline-block;width:20px;margin-right:8px;text-align:center}.sidebar--menu .icon svg{max-width:16px;max-height:16px;fill:var(--sidebar-text)}.sidebar--menu .nav-pills__container{padding-top:5px}.sidebar--menu .nav>li>a,.sidebar--menu .nav>li>button{padding:0 15px;background:none !important;color:inherit;font-size:15px;line-height:40px}.sidebar--menu .nav>li>a svg,.sidebar--menu .nav>li>button svg{position:relative;top:4px;width:18px;height:18px;fill-opacity:.85}.sidebar--menu .nav>li>a .icon,.sidebar--menu .nav>li>button .icon{position:relative;left:-5px;display:inline-block;width:25px;text-align:center}.sidebar--menu .nav>li>a .mentions,.sidebar--menu .nav>li>button .mentions{font-size:17px;font-weight:bold}

/*# sourceMappingURL=38.d3218aad56bc0f2a22b4.css.map*/