.app__body .modal .GenericModal.channel-bookmarks-create-modal .modal-body .form-control{height:40px;border:unset}.channel-bookmarks-create-modal .linkInput{margin-bottom:3rem;color:rgba(var(--center-channel-color-rgb), 0.72)}.channel-bookmarks-create-modal .Input___customMessage{line-height:14px}.channel-bookmarks-create-modal .LoadingSpinner{padding:10px 12px;font-size:16px}
#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body{display:flex;flex-direction:column;gap:20px;overflow-y:visible;transition:height 200ms ease}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.multi-team{min-height:340px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.single-team{height:230px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.loading{height:152px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.error{height:unset}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .new-channel-modal__url{margin-top:-20px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .loadingIndicator{display:block;width:32px;height:32px;margin:36px auto 48px;font-size:32px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .conversion-error{color:var(--error-text)}#convert-gm-to-channel-modal .DropDown__menu{z-index:999;max-height:120px}#convert-gm-to-channel-modal .DropDown__menu-list{z-index:999;max-height:120px}#convert-gm-to-channel-modal .modal-body{overflow:visible}

/*# sourceMappingURL=4418.51a20de0dd7a01f92797.css.map*/