@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.hfroute-header{position:relative;display:flex;width:100%;max-width:1520px;min-height:100px;align-self:center;padding:0 40px}.hfroute-header .header-main{display:flex;width:100%;height:100%;flex-flow:wrap;align-items:center;justify-content:space-between}.hfroute-header .header-main .header-logo-link{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;display:flex;color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Metropolis";font-size:20px;font-weight:500;line-height:28px;text-decoration:none}.hfroute-header .header-main .header-logo-link:hover,.hfroute-header .header-main .header-logo-link:active,.hfroute-header .header-main .header-logo-link:focus{text-decoration-line:underline}.hfroute-header .header-main .header-logo-link:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.hfroute-header .header-main .header-logo-link:hover,.hfroute-header .header-main .header-logo-link:active,.hfroute-header .header-main .header-logo-link:visited,.hfroute-header .header-main .header-logo-link:link{text-decoration:none}.hfroute-header .header-main .header-logo-link:focus{padding:8px;border:2px solid var(--sidebar-text-active-border);margin-left:-10px}.hfroute-header .header-main .header-logo-link svg{width:170px;fill:var(--center-channel-color)}.hfroute-header .header-main .header-logo-link .freeBadge{position:relative;top:1px;display:flex;align-self:center;padding:2px 6px;border-radius:var(--radius-s);margin-left:12px;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75);font-family:"Open Sans",sans-serif;font-size:10px;font-weight:600;letter-spacing:.025em;line-height:16px}.hfroute-header .header-back-button{position:absolute;top:unset;bottom:-8px;width:auto;padding:0 0 0 40px;background:none}.hfroute-header .header-back-button a{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px}.hfroute-header .header-back-button a:hover,.hfroute-header .header-back-button a:active,.hfroute-header .header-back-button a:focus{text-decoration-line:underline}.hfroute-header .header-back-button a:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.hfroute-header.has-custom-site-name .header-logo-link~.header-logo-link{margin-top:12px}.hfroute-header.has-free-banner.has-custom-site-name .header-back-button{bottom:-20px}@media screen and (max-width: 699px){.hfroute-header{padding:0 24px}.hfroute-header .header-main .header-logo-link svg{width:145px}.hfroute-header .header-back-button{padding:0 0 0 24px}}

/*# sourceMappingURL=9392.e70c506ecfefb4ab8c8f.css.map*/