{{define "mfa_change_body"}}
<html>
<body>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="100%" style="margin-top: 20px; line-height: 1.7; color: #555;">
    <tr>
        <td>
            <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%" style="max-width: 660px; font-family: Helvetica, Arial, sans-serif; font-size: 14px; background: #FFF;">
                <tr>
                    <td style="border: 1px solid #ddd;">
                        <table align="center" border="0" cellpadding="0" cellspacing="0" width="100%" style="border-collapse: collapse;">
                            <tr>
                                <td style="padding: 20px 20px 10px; text-align:left;">
                                    <img src="{{.Props.SiteURL}}/static/images/logo-email.png" width="130px" style="opacity: 0.5" alt="">
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <table border="0" cellpadding="0" cellspacing="0" style="padding: 20px 50px 0; text-align: center; margin: 0 auto">
                                        <tr>
                                            <td style="border-bottom: 1px solid #ddd; padding: 0 0 20px;">
                                                <h2 style="font-weight: normal; margin-top: 10px;">{{.Props.Title}}</h2>
                                                <p>{{.Props.Info}}<br>{{.Props.Warning}}</p>
                                            </td>
                                        </tr>
                                        <tr>
                                            {{template "email_info" . }}
                                        </tr>
                                    </table>
                                </td>
                            </tr>
                            <tr>
                                {{template "email_footer" . }}
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
</table>
</body>
</html>
{{end}}
