.userSettingDesktopHeader{display:flex;align-items:center;justify-content:space-between}.userSettingDesktopHeader .userSettingDesktopHeaderInfo{margin-top:-20px}.userSettingDesktopHeader .userSettingDesktopHeaderInfo span .btn{height:unset}.userSettingDesktopHeader .userSettingDesktopHeaderInfo a{font-size:12px}.userSettingDesktopHeader .userSettingDesktopHeaderInfo svg.circular-border{width:18px;height:18px;padding:2px;border-radius:50%;background:rgba(var(--button-bg-rgb), 0.12);text-align:center}
.mm-modal-generic-section-item{display:flex;flex-direction:column;gap:8px}.mm-modal-generic-section-item__title{display:flex;align-items:center;padding:0;margin:0 0 8px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.mm-modal-generic-section-item__description{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error{display:flex;align-items:center;padding:0;margin:12px 0 0 0;color:var(--error-text);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error svg{flex-shrink:0;margin-right:6px}.mm-modal-generic-section-item__content{display:flex;flex-direction:column}.mm-modal-generic-section-item__content.inline{flex-direction:row;gap:24px}.mm-modal-generic-section-item__fieldset-checkbox-ctr{display:flex;flex-direction:row;align-items:center;margin-bottom:5px;gap:8px}.mm-modal-generic-section-item__fieldset-checkbox{display:flex;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-checkbox span{font-weight:400}.mm-modal-generic-section-item__fieldset-radio{display:flex;flex-direction:column;gap:12px}.mm-modal-generic-section-item__label-radio{display:flex;width:fit-content;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-react-select{max-width:240px;flex-grow:1}.mm-modal-generic-section-item__input-checkbox{width:1.6rem;height:1.6rem}.mm-modal-generic-section-item input[type=checkbox]{display:grid;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.mm-modal-generic-section-item input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=checkbox]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=checkbox]:checked{border-color:var(--button-bg);background:var(--button-bg)}.mm-modal-generic-section-item input[type=radio]{display:grid;width:1.6rem;height:1.6rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:50%;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center}.mm-modal-generic-section-item input[type=radio]::before{width:8px;height:8px;border-radius:50%;background:var(--button-bg);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=radio]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=radio]:checked{border-color:var(--button-bg)}
.pluginActionContainer{margin-bottom:20px}
.access-history-modal{min-width:40vw}.access-history-modal .GenericModal__body{padding:24px 0 0}.access-history-modal .access-history-modal__body .table thead>tr>th,.access-history-modal .access-history-modal__body .table tbody>tr>td{border-color:rgba(var(--center-channel-color-rgb), 0.12)}
.activity-log-modal{min-width:40vw}.activity-log-modal .GenericModal__body{padding:24px 24px 0}
.UserSettingsModal .GenericModal__wrapper{display:flex;overflow:hidden;max-height:90vh;flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.UserSettingsModal .GenericModal__wrapper .modal-body{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;padding:28px 32px;gap:24px;overflow-x:hidden;overflow-y:auto}.UserSettingsModal .GenericModal__wrapper .modal-body main{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;gap:24px;overflow-x:hidden;overflow-y:auto}.UserSettingsModal__headerWrapper{display:flex;justify-content:space-between}.UserSettingsModal__headerWrapper .adminModeBadge{display:flex;width:86px;min-width:86px;height:22px;align-items:center;border-radius:4px;margin-top:10px;margin-bottom:auto;margin-left:24px;background:var(--error-text);color:#fff;font-size:12px;font-weight:600;gap:6px}.UserSettingsModal__headerWrapper .adminModeBadge span{margin:0 auto}@media screen and (max-width: 768px){.UserSettingsModal{max-width:100%;margin:0}.UserSettingsModal .modal-content{display:flex;height:100vh;max-height:unset;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.UserSettingsModal .modal-content{max-height:90vh}}@media screen and (max-height: 600px){.UserSettingsModal .modal-content,.UserSettingsModal .GenericModal__wrapper{max-height:85vh !important}}

/*# sourceMappingURL=3932.1691fcdad8cd39878453.css.map*/