.DndModal{width:600px}.DndModal .DayPickerInput-OverlayWrapper{position:initial}.DndModal .DayPickerInput-Overlay{top:42px;left:-1px;width:calc(100% + 2px)}.DndModal .DayPickerInput{position:absolute;top:0;left:0;display:block;display:flex;width:100%;height:100%;align-items:center;padding-left:40px}.DndModal .DayPicker-Day.DayPicker-Day--outside.DayPicker-Day--today{background-color:rgba(var(--center-channel-bg-rgb), 1)}.DndModal__content{display:flex;gap:16px}.DndModal__content>div{flex:1}.DndModal__content .dropdown-menu{overflow:auto;width:100%;max-height:268px}

/*# sourceMappingURL=9838.473b0a56f6f22f6b8f1d.css.map*/