"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[4986],{4986:(e,a,n)=>{n.r(a),n.d(a,{default:()=>l});var t=n(71633),s=n.n(t),c=n(36418),i=n.n(c),r=n(87383);const l=function(e){let{onClick:a,show:n=!1,extraClass:t="",content:c="",name:l}=e;return i().createElement("div",{id:"unreadIndicator"+l,className:s()("nav-pills__unread-indicator",{"nav-pills__unread-indicator--visible":n},t),onClick:a},i().createElement(r.A,{className:"icon icon__unread"}),c)}}}]);
//# sourceMappingURL=4986.ad3a0aaafeb5b3e1df7a.js.map