"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[9392],{39392:(e,a,t)=>{t.r(a),t.d(a,{default:()=>k});var l=t(71633),n=t.n(l),s=t(36418),c=t.n(s),r=t(37270),m=t(81911),o=t(26614),i=t(88153),u=t(68716),d=t(78451);const k=e=>{let{alternateLink:a,backButtonURL:t,onBackButtonClick:l}=e;const{SiteName:s}=(0,r.useSelector)(o.zj),k=(0,r.useSelector)(o.Ay),E=s||"Mattermost";let b=null;"false"===k.IsLicensed?b=c().createElement(c().Fragment,null,c().createElement(u.A,null),c().createElement("span",{className:"freeBadge"},"TEAM EDITION")):k.SkuShortName===d.gS.Entry&&(b=c().createElement(c().Fragment,null,c().createElement(u.A,null),c().createElement("span",{className:"freeBadge"},"ENTRY EDITION")));let f=s;return"Mattermost"===f&&(f=b?"":c().createElement(u.A,null)),c().createElement("div",{className:n()("hfroute-header",{"has-free-banner":b,"has-custom-site-name":f})},c().createElement("div",{className:"header-main"},c().createElement("div",null,b&&c().createElement(m.Link,{className:"header-logo-link",to:"/","aria-label":E},b),f&&c().createElement(m.Link,{className:"header-logo-link",to:"/","aria-label":E},f)),a),l&&c().createElement(i.A,{className:"header-back-button",url:t,onClick:l}))}},88153:(e,a,t)=>{t.d(a,{A:()=>o});var l=t(71633),n=t.n(l),s=t(36418),c=t.n(s),r=t(14778),m=t(81911);const o=e=>{let{url:a="/",className:t,onClick:l}=e;const{formatMessage:s}=(0,r.useIntl)();return c().createElement("div",{className:n()("signup-header",t)},c().createElement(m.Link,{"data-testid":"back_button",onClick:l,to:a},c().createElement("span",{id:"back_button_icon",className:"fa fa-1x fa-angle-left",title:s({id:"generic_icons.back",defaultMessage:"Back Icon"})}),c().createElement(r.FormattedMessage,{id:"web.header.back",defaultMessage:"Back"})))}}}]);
//# sourceMappingURL=9392.68796bf0c57bf14d1815.js.map